@@ -314,7 +314,7 @@ AddressEditDialog::AddressEditDialog( const KABC::Address::List &list,
   buttonBox->setSpacing( spacingHint() );
   topLayout->addWidget( buttonBox, 10, 0, 1, 2 );
 
-  QPushButton *addButton = new QPushButton( i18n( "New..." ), buttonBox );
+  QPushButton *addButton = new QPushButton( i18nc( "@action:button Add a new address", "New..." ), buttonBox );
   connect( addButton, SIGNAL( clicked() ), SLOT( addAddress() ) );
 
   mRemoveButton = new QPushButton( i18n( "Remove" ), buttonBox );
@@ -483,92 +483,11 @@ void AddressEditDialog::saveAddress( KABC::Address &addr )
 
 void AddressEditDialog::fillCountryCombo()
 {
-  QString country[] = {
-    i18n( "Afghanistan" ), i18n( "Albania" ), i18n( "Algeria" ),
-    i18n( "American Samoa" ), i18n( "Andorra" ), i18n( "Angola" ),
-    i18n( "Anguilla" ), i18n( "Antarctica" ), i18n( "Antigua and Barbuda" ),
-    i18n( "Argentina" ), i18n( "Armenia" ), i18n( "Aruba" ),
-    i18n( "Ashmore and Cartier Islands" ), i18n( "Australia" ),
-    i18n( "Austria" ), i18n( "Azerbaijan" ), i18n( "Bahamas" ),
-    i18n( "Bahrain" ), i18n( "Bangladesh" ), i18n( "Barbados" ),
-    i18n( "Belarus" ), i18n( "Belgium" ), i18n( "Belize" ),
-    i18n( "Benin" ), i18n( "Bermuda" ), i18n( "Bhutan" ),
-    i18n( "Bolivia" ), i18n( "Bosnia and Herzegovina" ), i18n( "Botswana" ),
-    i18n( "Brazil" ), i18n( "Brunei" ), i18n( "Bulgaria" ),
-    i18n( "Burkina Faso" ), i18n( "Burundi" ), i18n( "Cambodia" ),
-    i18n( "Cameroon" ), i18n( "Canada" ), i18n( "Cape Verde" ),
-    i18n( "Cayman Islands" ), i18n( "Central African Republic" ),
-    i18n( "Chad" ), i18n( "Chile" ), i18n( "China" ), i18n( "Colombia" ),
-    i18n( "Comoros" ), i18n( "Congo" ), i18n( "Congo, Dem. Rep." ),
-    i18n( "Costa Rica" ), i18n( "Croatia" ),
-    i18n( "Cuba" ), i18n( "Cyprus" ), i18n( "Czech Republic" ),
-    i18n( "Denmark" ), i18n( "Djibouti" ),
-    i18n( "Dominica" ), i18n( "Dominican Republic" ), i18n( "Ecuador" ),
-    i18n( "Egypt" ), i18n( "El Salvador" ), i18n( "Equatorial Guinea" ),
-    i18n( "Eritrea" ), i18n( "Estonia" ), i18n( "England" ),
-    i18n( "Ethiopia" ), i18n( "European Union" ), i18n( "Faroe Islands" ),
-    i18n( "Fiji" ), i18n( "Finland" ), i18n( "France" ),
-    i18n( "French Polynesia" ), i18n( "Gabon" ), i18n( "Gambia" ),
-    i18n( "Georgia" ), i18n( "Germany" ), i18n( "Ghana" ),
-    i18n( "Greece" ), i18n( "Greenland" ), i18n( "Grenada" ),
-    i18n( "Guam" ), i18n( "Guatemala" ), i18n( "Guinea" ),
-    i18n( "Guinea-Bissau" ), i18n( "Guyana" ), i18n( "Haiti" ),
-    i18n( "Honduras" ), i18n( "Hong Kong" ), i18n( "Hungary" ),
-    i18n( "Iceland" ), i18n( "India" ), i18n( "Indonesia" ),
-    i18n( "Iran" ), i18n( "Iraq" ), i18n( "Ireland" ),
-    i18n( "Israel" ), i18n( "Italy" ), i18n( "Ivory Coast" ),
-    i18n( "Jamaica" ), i18n( "Japan" ), i18n( "Jordan" ),
-    i18n( "Kazakhstan" ), i18n( "Kenya" ), i18n( "Kiribati" ),
-    i18n( "Korea, North" ), i18n( "Korea, South" ),
-    i18n( "Kuwait" ), i18n( "Kyrgyzstan" ), i18n( "Laos" ),
-    i18n( "Latvia" ), i18n( "Lebanon" ), i18n( "Lesotho" ),
-    i18n( "Liberia" ), i18n( "Libya" ), i18n( "Liechtenstein" ),
-    i18n( "Lithuania" ), i18n( "Luxembourg" ), i18n( "Macau" ),
-    i18n( "Madagascar" ), i18n( "Malawi" ), i18n( "Malaysia" ),
-    i18n( "Maldives" ), i18n( "Mali" ), i18n( "Malta" ),
-    i18n( "Marshall Islands" ), i18n( "Martinique" ), i18n( "Mauritania" ),
-    i18n( "Mauritius" ), i18n( "Mexico" ),
-    i18n( "Micronesia, Federated States Of" ), i18n( "Moldova" ),
-    i18n( "Monaco" ), i18n( "Mongolia" ), i18n( "Montserrat" ),
-    i18n( "Morocco" ), i18n( "Mozambique" ), i18n( "Myanmar" ),
-    i18n( "Namibia" ),
-    i18n( "Nauru" ), i18n( "Nepal" ), i18n( "Netherlands" ),
-    i18n( "Netherlands Antilles" ), i18n( "New Caledonia" ),
-    i18n( "New Zealand" ), i18n( "Nicaragua" ), i18n( "Niger" ),
-    i18n( "Nigeria" ), i18n( "Niue" ), i18n( "North Korea" ),
-    i18n( "Northern Ireland" ), i18n( "Northern Mariana Islands" ),
-    i18n( "Norway" ), i18n( "Oman" ), i18n( "Pakistan" ), i18n( "Palau" ),
-    i18n( "Palestinian" ), i18n( "Panama" ), i18n( "Papua New Guinea" ),
-    i18n( "Paraguay" ), i18n( "Peru" ), i18n( "Philippines" ),
-    i18n( "Poland" ), i18n( "Portugal" ), i18n( "Puerto Rico" ),
-    i18n( "Qatar" ), i18n( "Romania" ), i18n( "Russia" ), i18n( "Rwanda" ),
-    i18n( "St. Kitts and Nevis" ), i18n( "St. Lucia" ),
-    i18n( "St. Vincent and the Grenadines" ), i18n( "San Marino" ),
-    i18n( "Sao Tome and Principe" ), i18n( "Saudi Arabia" ),
-    i18n( "Senegal" ), i18n( "Serbia & Montenegro" ), i18n( "Seychelles" ),
-    i18n( "Sierra Leone" ), i18n( "Singapore" ), i18n( "Slovakia" ),
-    i18n( "Slovenia" ), i18n( "Solomon Islands" ), i18n( "Somalia" ),
-    i18n( "South Africa" ), i18n( "South Korea" ), i18n( "Spain" ),
-    i18n( "Sri Lanka" ), i18n( "St. Kitts and Nevis" ), i18n( "Sudan" ),
-    i18n( "Suriname" ), i18n( "Swaziland" ), i18n( "Sweden" ),
-    i18n( "Switzerland" ), i18n( "Syria" ), i18n( "Taiwan" ),
-    i18n( "Tajikistan" ), i18n( "Tanzania" ), i18n( "Thailand" ),
-    i18n( "Tibet" ), i18n( "Togo" ), i18n( "Tonga" ),
-    i18n( "Trinidad and Tobago" ), i18n( "Tunisia" ), i18n( "Turkey" ),
-    i18n( "Turkmenistan" ), i18n( "Turks and Caicos Islands" ),
-    i18n( "Tuvalu" ), i18n( "Uganda" ), i18n( "Ukraine" ),
-    i18n( "United Arab Emirates" ), i18n( "United Kingdom" ),
-    i18n( "United States" ), i18n( "Uruguay" ), i18n( "Uzbekistan" ),
-    i18n( "Vanuatu" ), i18n( "Vatican City" ), i18n( "Venezuela" ),
-    i18n( "Vietnam" ), i18n( "Western Samoa" ), i18n( "Yemen" ),
-    i18n( "Yugoslavia" ), i18n( "Zaire" ), i18n( "Zambia" ),
-    i18n( "Zimbabwe" ),
-    ""
-  };
-
   QStringList countries;
-  for ( int i = 0; !country[ i ].isEmpty(); ++i )
-    countries.append( country[ i ] );
+
+  foreach( const QString &cc, KGlobal::locale()->allCountriesList() ) {
+    countries.append( KGlobal::locale()->countryCodeToName(cc) );
+  }
 
   countries = sortLocaleAware( countries );
 
