@@ -21,31 +21,29 @@
     without including the source code for Qt in the source distribution.
 */
 
+#include "cardview.h"
 
 #include <limits.h>
 
-#include <QCursor>
-#include <QDateTime>
-#include <QLabel>
-#include <QPainter>
-#include <QStyle>
-#include <QStyleOption>
-#include <QTimer>
-#include <QToolTip>
-//Added by qt3to4:
-#include <QWheelEvent>
-#include <QFocusEvent>
-#include <Q3PtrList>
-#include <QEvent>
-#include <QKeyEvent>
-#include <QResizeEvent>
-#include <QMouseEvent>
+#include <Qt3Support/Q3PtrList>
+#include <QtCore/QDateTime>
+#include <QtCore/QEvent>
+#include <QtCore/QTimer>
+#include <QtGui/QCursor>
+#include <QtGui/QFocusEvent>
+#include <QtGui/QKeyEvent>
+#include <QtGui/QLabel>
+#include <QtGui/QMouseEvent>
+#include <QtGui/QPainter>
+#include <QtGui/QResizeEvent>
+#include <QtGui/QStyle>
+#include <QtGui/QStyleOption>
+#include <QtGui/QToolTip>
+#include <QtGui/QWheelEvent>
 
 #include <kdebug.h>
 #include <kglobalsettings.h>
 
-#include "cardview.h"
-
 #define MIN_ITEM_WIDTH 80
 
 class CardViewTip : public QLabel
@@ -55,6 +53,7 @@ class CardViewTip : public QLabel
       : QLabel( parent )
     {
       setObjectName( name );
+      setAutoFillBackground( true );
       setPalette( QToolTip::palette() );
       setFrameStyle( Panel | Plain );
       setMidLineWidth( 0 );
@@ -311,7 +310,7 @@ void CardViewItem::paintCard( QPainter *p, const QPalette &pal )
       p->drawText( labelXPos, yPos, label + ':' );
     }
 
-    for ( cln = 0; cln <= maxLines; cln++ ) {
+    for ( cln = 0; cln <= maxLines; ++cln ) {
       tmp = value.section( '\n', cln, cln );
       if ( !tmp.isEmpty() )
         p->drawText( valueXPos, yPos + cln * fh, trimString( tmp, valueWidth, fm ) );
@@ -1082,7 +1081,7 @@ void CardView::contentsMousePressEvent( QMouseEvent *e )
       to = a > b ? a : b;
 
       CardViewItem *aItem;
-      for ( ; from <= to; from++ ) {
+      for ( ; from <= to; ++from ) {
         aItem = d->mItemList.at( from );
         aItem->setSelected( s );
         repaintItem( aItem );
@@ -1366,7 +1365,7 @@ void CardView::keyPressEvent( QKeyEvent *e )
         }
 
         CardViewItem *item;
-        for ( ; from <= to; from++ ) {
+        for ( ; from <= to; ++from ) {
           item = d->mItemList.at( from );
           item->setSelected( s );
           repaintItem( item );
