@@ -21,15 +21,16 @@
     without including the source code for Qt in the source distribution.
 */
 
-#include <QApplication>
-#include <q3iconview.h>
-#include <QStringList>
-//Added by qt3to4:
-#include <QPixmap>
-#include <QKeyEvent>
-#include <QEvent>
-#include <QDropEvent>
-#include <QVBoxLayout>
+#include "kaddressbookiconview.h"
+
+#include <QtCore/QEvent>
+#include <QtCore/QStringList>
+#include <QtGui/QApplication>
+#include <QtGui/QDropEvent>
+#include <QtGui/QKeyEvent>
+#include <QtGui/QPixmap>
+#include <QtGui/QVBoxLayout>
+#include <Qt3Support/Q3IconView>
 
 #include <kabc/addressbook.h>
 #include <kabc/addressee.h>
@@ -42,8 +43,6 @@
 #include "core.h"
 #include "kabprefs.h"
 
-#include "kaddressbookiconview.h"
-
 class IconViewFactory : public ViewFactory
 {
   public:
