@@ -249,7 +249,7 @@ static QString buildPhoneInfoString( const gn_memory_status &memstat )
 		.arg(format.arg(i18n("Revision")).arg(GN_FROM(revision)))
 		.arg(format.arg(i18n("IMEI")).arg(GN_FROM(imei)))
 		.arg(format.arg(i18n("Phonebook status"))
-			   .arg(i18n("%1 out of %2 contacts used", memstat.used, memstat.used+memstat.free)));
+			   .arg(i18np("%2 out of 1 contact used", "%2 out of %1 contacts used", memstat.used+memstat.free, memstat.used)));
 }
 
 static QString buildMemoryTypeString( gn_memory_type memtype )
@@ -285,7 +285,8 @@ static gn_error read_phone_entries( const char *memtypestr, gn_memory_type memty
   QString s, country;
 
   progress->setMaximum(memstat.used);
-  m_progressDlg->setLabelText(i18n("<qt>Importing <b>%1</b> contacts from <b>%2</b> of the Mobile Phone.<br /><br />%3</qt>",
+  m_progressDlg->setLabelText(i18np(	  "<qt>Importing <b>1</b> contact from <b>%2</b> of the Mobile Phone.<br /><br />%3</qt>",
+					"<qt>Importing <b>%1</b> contacts from <b>%2</b> of the Mobile Phone.<br /><br/>%3</qt>",
 		 memstat.used,
 		 buildMemoryTypeString(memtype),
 		 buildPhoneInfoString(memstat)) );
@@ -321,14 +322,14 @@ static gn_error read_phone_entries( const char *memtypestr, gn_memory_type memty
 		  } else {
 			// multiple strings -> split them.
 			a->setFamilyName(addrlist.last().simplified());
-			addrlist.remove(addrlist.last());
+			addrlist.removeLast();
 			a->setGivenName(addrlist.join(" ").simplified());
 		  }
 		} else {
 		  // assumed format: "familyname, ... givenname"
 		  addrlist = s.split(',', QString::SkipEmptyParts);
 		  a->setFamilyName(addrlist.first().simplified());
-		  addrlist.remove(addrlist.first());
+		  addrlist.removeFirst();
 		  a->setGivenName(addrlist.join(" ").simplified());
 		}
 
@@ -468,7 +469,7 @@ KABC::Addressee::List GNOKIIXXPort::importContacts( const QString& ) const
 		     "<b>Continue</b> to start importing the personal contacts.<br /><br />"
 		     "Please note that if your Mobile Phone is not properly connected "
 		     "the following detection phase might take up to two minutes, during which "
-                     "KAddressbook will behave unresponsively.</qt>") ))
+                     "KAddressBook will be unresponsive.</qt>") ))
 	  return addrList;
 
 	m_progressDlg = new KProgressDialog( parentWidget(),
@@ -483,9 +484,7 @@ KABC::Addressee::List GNOKIIXXPort::importContacts( const QString& ) const
 	m_progressDlg->show();
   	processEvents();
 
-#if (QT_VERSION >= 0x030300)
 	m_progressDlg->setCursor( Qt::BusyCursor );
-#endif
 	QString errStr = businit();
 	m_progressDlg->unsetCursor();
 
@@ -716,7 +715,7 @@ bool GNOKIIXXPort::exportContacts( const KABC::AddresseeList &list, const QStrin
 		     "<b>Continue</b> to start exporting the selected personal contacts.<br /><br />"
 		     "Please note that if your Mobile Phone is not properly connected "
 		     "the following detection phase might take up to two minutes, during which "
-		     "KAddressbook will behave unresponsively.</qt>") ))
+		     "KAddressBook will be unresponsive.</qt>") ))
 	  return false;
 
 	m_progressDlg = new KProgressDialog( parentWidget(),
@@ -792,11 +791,13 @@ bool GNOKIIXXPort::exportContacts( const KABC::AddresseeList &list, const QStrin
 	entries_written = 0;
 	progress->setValue(entries_written);
 	m_progressDlg->setButtonText(i18n("&Stop Export"));
-	m_progressDlg->setLabelText(i18n("<qt>Exporting <b>%1</b> contacts to the <b>%2</b> "
-			"of the Mobile Phone.<br /><br />%3</qt>",
-		 list.count(),
-		 buildMemoryTypeString(memtype),
-		 buildPhoneInfoString(memstat)) );
+	m_progressDlg->setLabelText(i18np("<qt>Exporting <b>1</b> contact to the <b>%2</b> "
+		                            "of the Mobile Phone.<br /><br />%3</qt>",
+					  "<qt>Exporting <b>%1</b> contacts to the <b>%2</b> "
+					    "of the Mobile Phone.<br /><br />%3</qt>",
+					 list.count(),
+					 buildMemoryTypeString(memtype),
+					 buildPhoneInfoString(memstat)) );
 
 	// Now run the loop...
 	phone_entry_no = 1;
@@ -805,7 +806,7 @@ bool GNOKIIXXPort::exportContacts( const KABC::AddresseeList &list, const QStrin
 		if (addr->isEmpty())
 			continue;
 		// don't write back SIM-card entries !
-		if (addr->custom(APP, "X_GSM_STORE_AT").startsWith("SM"))
+		if (addr->custom(APP, "X_GSM_STORE_AT").startsWith(QLatin1String("SM")))
 			continue;
 
 		progress->setValue(entries_written++);
