@@ -457,6 +457,7 @@ class KAEvent : public KAAlarmEventBase
 		bool               setRecurAnnualByDate(int freq, const QList<int>& months, int day, Preferences::Feb29Type, int count, const QDate& end);
 		bool               setRecurAnnualByPos(int freq, const QList<MonthPos>& pos, const QList<int>& months, int count, const QDate& end);
 //		static QValueList<MonthPos> convRecurPos(const QValueList<KCal::RecurrenceRule::WDayPos>&);
+		void               adjustRecurrenceStartOfDay();
 #ifdef NDEBUG
 		void               dumpDebug() const  { }
 #else
@@ -464,8 +465,7 @@ class KAEvent : public KAAlarmEventBase
 #endif
 		static int         calVersion();
 		static QString     calVersionString();
-		static bool        adjustStartOfDay(const KCal::Event::List&);
-		static bool        convertKCalEvents(KCal::CalendarLocal&, int version, bool adjustSummerTime);
+		static bool        convertKCalEvents(KCal::CalendarLocal&, int calendarVersion, bool adjustSummerTime);
 //		static bool        convertRepetitions(KCal::CalendarLocal&);
 
 	private:
@@ -487,6 +487,7 @@ class KAEvent : public KAAlarmEventBase
 		void               calcTriggerTimes() const;
 		void               calcNextWorkingTime(const DateTime& nextTrigger) const;
 		DateTime           nextWorkingTime() const;
+		static bool        convertStartOfDay(KCal::Event*);
 		static bool        convertRepetition(KCal::Event*);
 		KCal::Alarm*       initKCalAlarm(KCal::Event*, const DateTime&, const QStringList& types, KAAlarm::Type = KAAlarm::INVALID_ALARM) const;
 		KCal::Alarm*       initKCalAlarm(KCal::Event*, int startOffsetSecs, const QStringList& types, KAAlarm::Type = KAAlarm::INVALID_ALARM) const;
