@@ -1,7 +1,7 @@
 /*
  *  alarmtext.cpp  -  text/email alarm text conversion
  *  Program:  kalarm
- *  Copyright © 2004,2005,2007,2008 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2004,2005,2007-2009 by David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,8 +23,10 @@
 
 #include "alarmevent.h"
 
-#include <QStringList>
+#include <kcal/todo.h>
 #include <klocale.h>
+#include <kglobal.h>
+#include <QStringList>
 
 
 QString AlarmText::mFromPrefix;
@@ -32,6 +34,9 @@ QString AlarmText::mToPrefix;
 QString AlarmText::mCcPrefix;
 QString AlarmText::mDatePrefix;
 QString AlarmText::mSubjectPrefix;
+QString AlarmText::mTitlePrefix;
+QString AlarmText::mLocnPrefix;
+QString AlarmText::mDuePrefix;
 QString AlarmText::mFromPrefixEn    = QLatin1String("From:");
 QString AlarmText::mToPrefixEn      = QLatin1String("To:");
 QString AlarmText::mCcPrefixEn      = QLatin1String("Cc:");
@@ -39,11 +44,10 @@ QString AlarmText::mDatePrefixEn    = QLatin1String("Date:");
 QString AlarmText::mSubjectPrefixEn = QLatin1String("Subject:");
 
 
-void AlarmText::setText(const QString& text)
+void AlarmText::clear()
 {
-	mBody     = text;
-	mIsScript = text.startsWith(QLatin1String("#!"));
-	mIsEmail  = false;
+	mType = None;
+	mBody.clear();
 	mTo.clear();
 	mFrom.clear();
 	mCc.clear();
@@ -52,11 +56,19 @@ void AlarmText::setText(const QString& text)
 	mKMailSerialNum = 0;
 }
 
+void AlarmText::setText(const QString& text)
+{
+	clear();
+	mBody = text;
+	if (text.startsWith(QLatin1String("#!")))
+		mType = Script;
+}
+
 void AlarmText::setEmail(const QString& to, const QString& from, const QString& cc, const QString& time,
                          const QString& subject, const QString& body, unsigned long kmailSerialNumber)
 {
-	mIsScript       = false;
-	mIsEmail        = true;
+	clear();
+	mType           = Email;
 	mTo             = to;
 	mFrom           = from;
 	mCc             = cc;
@@ -66,31 +78,68 @@ void AlarmText::setEmail(const QString& to, const QString& from, const QString&
 	mKMailSerialNum = kmailSerialNumber;
 }
 
+void AlarmText::setTodo(const KCal::Todo* todo)
+{
+	clear();
+	mType    = Todo;
+	mSubject = todo->summary();
+	mBody    = todo->description();
+	mTo      = todo->location();
+	if (todo->hasDueDate())
+	{
+		KDateTime due = todo->dtDue(false);   // fetch the next due date
+		if (todo->hasStartDate()  &&  todo->dtStart() != due)
+		{
+			mTime = todo->allDay() ? KGlobal::locale()->formatDate(due.date(), KLocale::ShortDate)
+			                       : KGlobal::locale()->formatDateTime(due.dateTime());
+		}
+	}
+}
+
 /******************************************************************************
 *  Return the text for a text message alarm, in display format.
 */
 QString AlarmText::displayText() const
 {
-	if (mIsEmail)
+	QString text;
+	switch (mType)
 	{
-		// Format the email into a text alarm
-		setUpTranslations();
-		QString text;
-		text = mFromPrefix + '\t' + mFrom + '\n';
-		text += mToPrefix + '\t' + mTo + '\n';
-		if (!mCc.isEmpty())
-			text += mCcPrefix + '\t' + mCc + '\n';
-		if (!mTime.isEmpty())
-			text += mDatePrefix + '\t' + mTime + '\n';
-		text += mSubjectPrefix + '\t' + mSubject;
-		if (!mBody.isEmpty())
-		{
-			text += "\n\n";
-			text += mBody;
-		}
-		return text;
+		case Email:
+			// Format the email into a text alarm
+			setUpTranslations();
+			text = mFromPrefix + '\t' + mFrom + '\n';
+			text += mToPrefix + '\t' + mTo + '\n';
+			if (!mCc.isEmpty())
+				text += mCcPrefix + '\t' + mCc + '\n';
+			if (!mTime.isEmpty())
+				text += mDatePrefix + '\t' + mTime + '\n';
+			text += mSubjectPrefix + '\t' + mSubject;
+			if (!mBody.isEmpty())
+			{
+				text += "\n\n";
+				text += mBody;
+			}
+			break;
+		case Todo:
+			// Format the todo into a text alarm
+			setUpTranslations();
+			if (!mSubject.isEmpty())
+				text = mTitlePrefix + '\t' + mSubject + '\n';
+			if (!mTo.isEmpty())
+				text += mLocnPrefix + '\t' + mTo + '\n';
+			if (!mTime.isEmpty())
+				text += mDuePrefix + '\t' + mTime + '\n';
+			if (!mBody.isEmpty())
+			{
+				if (!text.isEmpty())
+					text += '\n';
+				text += mBody;
+			}
+			break;
+		default:
+			break;
 	}
-	return mBody;
+	return !text.isEmpty() ? text : mBody;
 }
 
 /******************************************************************************
@@ -100,7 +149,7 @@ bool AlarmText::isEmpty() const
 {
 	if (!mBody.isEmpty())
 		return false;
-	if (!mIsEmail)
+	if (mType != Email)
 		return true;
 	return mFrom.isEmpty() && mTo.isEmpty() && mCc.isEmpty() && mTime.isEmpty() && mSubject.isEmpty();
 }
@@ -159,6 +208,39 @@ QString AlarmText::emailHeaders(const QString& text, bool subjectOnly)
 	return h;
 }
 
+/******************************************************************************
+* Return the Todo title line, if the text is for a Todo.
+*/
+QString AlarmText::todoTitle(const QString& text)
+{
+	setUpTranslations();
+	QStringList lines = text.split('\n', QString::SkipEmptyParts);
+	int n;
+	for (n = 0;  n < lines.count() && lines[n].contains('\t');  ++n) ;
+	if (!n  ||  n > 3)
+		return QString();
+	QString title;
+	int i = 0;
+	if (lines[i].startsWith(mTitlePrefix + '\t'))
+	{
+		title = lines[i].mid(mTitlePrefix.length()).trimmed();
+		++i;
+	}
+	if (i < n  &&  lines[i].startsWith(mLocnPrefix + '\t'))
+		++i;
+	if (i < n  &&  lines[i].startsWith(mDuePrefix + '\t'))
+		++i;
+	if (i == n)
+	{
+		// It's a Todo text
+		if (!title.isEmpty())
+			return title;
+		if (n < lines.count())
+			return lines[n];
+	}
+	return QString();
+}
+
 /******************************************************************************
 *  Translate an alarm calendar text to a display text.
 *  Translation is needed for email texts, since the alarm calendar stores
@@ -250,6 +332,10 @@ void AlarmText::setUpTranslations()
 		mCcPrefix      = i18nc("@info/plain Copy-to in email headers", "Cc:");
 		mDatePrefix    = i18nc("@info/plain", "Date:");
 		mSubjectPrefix = i18nc("@info/plain Email subject", "Subject:");
+		// Todo prefixes
+		mTitlePrefix   = i18nc("@info/plain Todo calendar item's title field", "To-do:");
+		mLocnPrefix    = i18nc("@info/plain Todo calendar item's location field", "Location:");
+		mDuePrefix     = i18nc("@info/plain Todo calendar item's due date/time", "Due:");
 	}
 }
 
@@ -272,6 +358,18 @@ QString AlarmText::summary(const KAEvent* event, int maxLines, bool* truncated)
 				*truncated = true;
 			return subject;
 		}
+		if (maxLines == 1)
+		{
+			// If the message is the text of a todo, return either the
+			// title/description or the whole text.
+			subject = todoTitle(text);
+			if (!subject.isEmpty())
+			{
+				if (truncated)
+					*truncated = true;
+				return subject;
+			}
+		}
 	}
 	if (truncated)
 		*truncated = false;
