@@ -1,7 +1,7 @@
 /*
  *  editdlg.h  -  dialog to create or modify an alarm or alarm template
  *  Program:  kalarm
- *  Copyright © 2001-2008 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2001-2009 by David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -54,7 +54,7 @@ class EditAlarmDlg : public KDialog
 {
 		Q_OBJECT
 	public:
-		enum Type { DISPLAY, COMMAND, EMAIL };
+		enum Type { NO_TYPE, DISPLAY, COMMAND, EMAIL };
 		enum GetResourceType {
 			RES_PROMPT,        // prompt for resource
 			RES_USE_EVENT_ID,  // use resource containing event, or prompt if not found
@@ -67,7 +67,17 @@ class EditAlarmDlg : public KDialog
 		                            GetResourceType = RES_PROMPT, bool readOnly = false);
 		virtual ~EditAlarmDlg();
 		bool            getEvent(KAEvent&, AlarmResource*&);
+
+		// Methods to initialise values in the New Alarm dialogue.
+		// N.B. setTime() must be called first to set the date-only characteristic,
+		//      followed by setRecurrence() if applicable.
+		void            setTime(const DateTime&);    // must be called first to set date-only value
+		void            setRecurrence(const KARecurrence&, int subRepeatInterval, int subRepeatCount);
+		void            setRepeatAtLogin();
 		virtual void    setAction(KAEvent::Action, const AlarmText& = AlarmText()) = 0;
+		void            setLateCancel(int minutes);
+		void            setShowInKOrganizer(bool);
+
 		virtual QSize   sizeHint() const    { return minimumSizeHint(); }
 
 		static QString  i18n_chk_ShowInKOrganizer();   // text of 'Show in KOrganizer' checkbox
@@ -108,6 +118,8 @@ class EditAlarmDlg : public KDialog
 		virtual void    slotHelp();      // Load Template
 		virtual void    slotDefault();   // More/Less Options
 		virtual void    slotButtonClicked(int button);
+		void            contentsChanged();
+
 	private slots:
 		void            slotRecurTypeChange(int repeatType);
 		void            slotRecurFrequencyChange();
@@ -188,6 +200,7 @@ class EditAlarmDlg : public KDialog
 		int                 mSavedTemplateAfterTime;// mTemplateAfterTime value
 		QString             mSavedTextFileCommandMessage;  // mTextMessageEdit/mFileMessageEdit/mCmdCommandEdit/mEmailMessageEdit value
 		KDateTime           mSavedDateTime;         // mTimeWidget value
+		KDateTime           mSavedDeferTime;        // mDeferDateTime value
 		int                 mSavedRecurrenceType;   // RecurrenceEdit::RepeatType value
 		int                 mSavedLateCancel;       // mLateCancel value
 		bool                mSavedShowInKorganizer; // mShowInKorganizer status
