@@ -153,6 +153,7 @@ void EditDisplayAlarmDlg::type_init(QWidget* parent, QVBoxLayout* frameLayout)
 	mTypeCombo->setFixedSize(mTypeCombo->sizeHint());
 	mTypeCombo->setCurrentIndex(-1);    // ensure slotAlarmTypeChanged() is called when index is set
 	connect(mTypeCombo, SIGNAL(currentIndexChanged(int)), SLOT(slotAlarmTypeChanged(int)));
+	connect(mTypeCombo, SIGNAL(currentIndexChanged(int)), SLOT(contentsChanged()));
 	label->setBuddy(mTypeCombo);
 	box->setWhatsThis(i18nc("@info:whatsthis", "<para>Select what the alarm should display:"
 	      "<list><item><interface>%1</interface>: the alarm will display the text message you type in.</item>"
@@ -166,6 +167,7 @@ void EditDisplayAlarmDlg::type_init(QWidget* parent, QVBoxLayout* frameLayout)
 	mTextMessageEdit = new TextEdit(parent);
 	mTextMessageEdit->setLineWrapMode(KTextEdit::NoWrap);
 	mTextMessageEdit->setWhatsThis(i18nc("@info:whatsthis", "Enter the text of the alarm message. It may be multi-line."));
+	connect(mTextMessageEdit, SIGNAL(textChanged()), SLOT(contentsChanged()));
 	frameLayout->addWidget(mTextMessageEdit);
 
 	// File name edit box
@@ -175,6 +177,7 @@ void EditDisplayAlarmDlg::type_init(QWidget* parent, QVBoxLayout* frameLayout)
 	mFileMessageEdit = new LineEdit(LineEdit::Url, mFileBox);
 	mFileMessageEdit->setAcceptDrops(true);
 	mFileMessageEdit->setWhatsThis(i18nc("@info:whatsthis", "Enter the name or URL of a text or image file to display."));
+	connect(mFileMessageEdit, SIGNAL(textChanged(const QString&)), SLOT(contentsChanged()));
 
 	// File browse button
 	mFileBrowseButton = new QPushButton(mFileBox);
@@ -187,8 +190,9 @@ void EditDisplayAlarmDlg::type_init(QWidget* parent, QVBoxLayout* frameLayout)
 
 	// Command type checkbox and edit box
 	mCmdEdit = new CommandEdit(parent);
-	frameLayout->addWidget(mCmdEdit);
 	connect(mCmdEdit, SIGNAL(scriptToggled(bool)), SLOT(slotCmdScriptToggled(bool)));
+	connect(mCmdEdit, SIGNAL(changed()), SLOT(contentsChanged()));
+	frameLayout->addWidget(mCmdEdit);
 
 	// Sound checkbox and file selector
 	QHBoxLayout* hlayout = new QHBoxLayout();
@@ -196,6 +200,7 @@ void EditDisplayAlarmDlg::type_init(QWidget* parent, QVBoxLayout* frameLayout)
 	frameLayout->addLayout(hlayout);
 	mSoundPicker = new SoundPicker(parent);
 	mSoundPicker->setFixedSize(mSoundPicker->sizeHint());
+	connect(mSoundPicker, SIGNAL(changed()), SLOT(contentsChanged()));
 	hlayout->addWidget(mSoundPicker);
 	hlayout->addSpacing(2*spacingHint());
 	hlayout->addStretch();
@@ -205,12 +210,14 @@ void EditDisplayAlarmDlg::type_init(QWidget* parent, QVBoxLayout* frameLayout)
 	mFontColourButton->setMaximumHeight(mFontColourButton->sizeHint().height() * 3/2);
 	hlayout->addWidget(mFontColourButton);
 	connect(mFontColourButton, SIGNAL(selected(const QColor&, const QColor&)), SLOT(setColours(const QColor&, const QColor&)));
+	connect(mFontColourButton, SIGNAL(selected(const QColor&, const QColor&)), SLOT(contentsChanged()));
 
 	if (ShellProcess::authorised())    // don't display if shell commands not allowed (e.g. kiosk mode)
 	{
 		// Special actions button
 		mSpecialActionsButton = new SpecialActionsButton(false, parent);
 		mSpecialActionsButton->setFixedSize(mSpecialActionsButton->sizeHint());
+		connect(mSpecialActionsButton, SIGNAL(selected()), SLOT(contentsChanged()));
 		frameLayout->addWidget(mSpecialActionsButton, 0, Qt::AlignRight);
 	}
 
@@ -385,6 +392,41 @@ void EditDisplayAlarmDlg::setAction(KAEvent::Action action, const AlarmText& ala
 	}
 }
 
+/******************************************************************************
+* Initialise various values in the New Alarm dialogue.
+*/
+void EditDisplayAlarmDlg::setBgColour(const QColor& colour)
+{
+	mFontColourButton->setBgColour(colour);
+	setColours(mFontColourButton->fgColour(), colour);
+}
+void EditDisplayAlarmDlg::setFgColour(const QColor& colour)
+{
+	mFontColourButton->setFgColour(colour);
+	setColours(colour, mFontColourButton->bgColour());
+}
+void EditDisplayAlarmDlg::setConfirmAck(bool confirm)
+{
+	mConfirmAck->setChecked(confirm);
+}
+void EditDisplayAlarmDlg::setAutoClose(bool close)
+{
+	lateCancel()->setAutoClose(close);
+}
+void EditDisplayAlarmDlg::setAudio(Preferences::SoundType type, const QString& file, float volume, bool repeat)
+{
+	mSoundPicker->set(type, file, volume, -1, 0, repeat);
+}
+void EditDisplayAlarmDlg::setReminder(int minutes)
+{
+	bool onceOnly = (minutes < 0);
+	if (onceOnly)
+		minutes = -minutes;
+	reminder()->setMinutes(minutes, dateOnly());
+	reminder()->setOnceOnly(onceOnly);
+	reminder()->enableOnceOnly(isTimedRecurrence());
+}
+
 /******************************************************************************
 * Set the read-only status of all non-template controls.
 */
@@ -583,7 +625,10 @@ void EditDisplayAlarmDlg::slotPickFile()
 	QString file = KAlarm::browseFile(i18nc("@title:window", "Choose Text or Image File to Display"),
 	                                  defaultDir, mFileMessageEdit->text(), QString(), KFile::ExistingOnly, this);
 	if (!file.isEmpty())
+	{
 		mFileMessageEdit->setText(file);
+		contentsChanged();
+	}
 }
 
 /******************************************************************************
@@ -666,6 +711,12 @@ bool EditDisplayAlarmDlg::checkText(QString& result, bool showErrorMessage) cons
 			}
 			if (err  &&  showErrorMessage)
 			{
+				// If file is a local file, remove "file://" from name
+				QString file = alarmtext;
+				QRegExp f("^file://*");
+				if (f.indexIn(file) >= 0)
+					file = file.mid(f.matchedLength() - 1);
+
 				mFileMessageEdit->setFocus();
 				QString errmsg;
 				switch (err)
@@ -673,10 +724,12 @@ bool EditDisplayAlarmDlg::checkText(QString& result, bool showErrorMessage) cons
 					case BLANK:
 						KMessageBox::sorry(const_cast<EditDisplayAlarmDlg*>(this), i18nc("@info", "Please select a file to display"));
 						return false;
-					case NONEXISTENT:     errmsg = i18nc("@info", "<filename>%1</filename> not found", alarmtext);  break;
-					case DIRECTORY:       errmsg = i18nc("@info", "<filename>%1</filename> is a folder", alarmtext);  break;
-					case UNREADABLE:      errmsg = i18nc("@info", "<filename>%1</filename> is not readable", alarmtext);  break;
-					case NOT_TEXT_IMAGE:  errmsg = i18nc("@info", "<filename>%1</filename> appears not to be a text or image file", alarmtext);  break;
+					case DIRECTORY:
+						KMessageBox::sorry(const_cast<EditDisplayAlarmDlg*>(this), i18nc("@info", "<filename>%1</filename> is a folder", file));
+						return false;
+					case NONEXISTENT:     errmsg = i18nc("@info", "<filename>%1</filename> not found", file);  break;
+					case UNREADABLE:      errmsg = i18nc("@info", "<filename>%1</filename> is not readable", file);  break;
+					case NOT_TEXT_IMAGE:  errmsg = i18nc("@info", "<filename>%1</filename> appears not to be a text or image file", file);  break;
 					case NONE:
 					default:
 						break;
@@ -746,6 +799,7 @@ void EditCommandAlarmDlg::type_init(QWidget* parent, QVBoxLayout* frameLayout)
 
 	mCmdEdit = new CommandEdit(parent);
 	connect(mCmdEdit, SIGNAL(scriptToggled(bool)), SLOT(slotCmdScriptToggled(bool)));
+	connect(mCmdEdit, SIGNAL(changed()), SLOT(contentsChanged()));
 	frameLayout->addWidget(mCmdEdit);
 
 	// What to do with command output
@@ -756,6 +810,7 @@ void EditCommandAlarmDlg::type_init(QWidget* parent, QVBoxLayout* frameLayout)
 	vlayout->setMargin(marginHint());
 	vlayout->setSpacing(spacingHint());
 	mCmdOutputGroup = new ButtonGroup(mCmdOutputBox);
+	connect(mCmdOutputGroup, SIGNAL(buttonSet(QAbstractButton*)), SLOT(contentsChanged()));
 
 	// Execute in terminal window
 	mCmdExecInTerm = new RadioButton(i18n_radio_ExecInTermWindow(), mCmdOutputBox);
@@ -771,6 +826,7 @@ void EditCommandAlarmDlg::type_init(QWidget* parent, QVBoxLayout* frameLayout)
 	mCmdLogFileEdit = new LineEdit(LineEdit::Url, box);
 	mCmdLogFileEdit->setAcceptDrops(true);
 	mCmdLogFileEdit->setWhatsThis(i18nc("@info:whatsthis", "Enter the name or path of the log file."));
+	connect(mCmdLogFileEdit, SIGNAL(textChanged(const QString&)), SLOT(contentsChanged()));
 
 	// Log file browse button.
 	// The file browser dialog is activated by the PickLogFileRadio class.
@@ -785,6 +841,7 @@ void EditCommandAlarmDlg::type_init(QWidget* parent, QVBoxLayout* frameLayout)
 	mCmdLogToFile = new PickLogFileRadio(browseButton, mCmdLogFileEdit, i18nc("@option:radio", "Log to file"), mCmdOutputGroup, mCmdOutputBox);
 	mCmdLogToFile->setFixedSize(mCmdLogToFile->sizeHint());
 	mCmdLogToFile->setWhatsThis(i18nc("@info:whatsthis", "Check to log the command output to a local file. The output will be appended to any existing contents of the file."));
+	connect(mCmdLogToFile, SIGNAL(fileChanged()), SLOT(contentsChanged()));
 	mCmdOutputGroup->addButton(mCmdLogToFile, Preferences::Log_File);
 	vlayout->addWidget(mCmdLogToFile, 0, Qt::AlignLeft);
 	vlayout->addWidget(box);
@@ -1054,6 +1111,7 @@ void EditEmailAlarmDlg::type_init(QWidget* parent, QVBoxLayout* frameLayout)
 		mEmailFromList->setMinimumSize(mEmailFromList->sizeHint());
 		label->setBuddy(mEmailFromList);
 		mEmailFromList->setWhatsThis(i18nc("@info:whatsthis", "Your email identity, used to identify you as the sender when sending email alarms."));
+		connect(mEmailFromList, SIGNAL(identityChanged(uint)), SLOT(contentsChanged()));
 		grid->addWidget(mEmailFromList, 0, 1, 1, 2);
 	}
 
@@ -1066,6 +1124,7 @@ void EditEmailAlarmDlg::type_init(QWidget* parent, QVBoxLayout* frameLayout)
 	mEmailToEdit->setMinimumSize(mEmailToEdit->sizeHint());
 	mEmailToEdit->setWhatsThis(i18nc("@info:whatsthis", "Enter the addresses of the email recipients. Separate multiple addresses by "
 	                                "commas or semicolons."));
+	connect(mEmailToEdit, SIGNAL(textChanged(const QString&)), SLOT(contentsChanged()));
 	grid->addWidget(mEmailToEdit, 1, 1);
 
 	mEmailAddressButton = new QPushButton(parent);
@@ -1086,11 +1145,13 @@ void EditEmailAlarmDlg::type_init(QWidget* parent, QVBoxLayout* frameLayout)
 	mEmailSubjectEdit->setMinimumSize(mEmailSubjectEdit->sizeHint());
 	label->setBuddy(mEmailSubjectEdit);
 	mEmailSubjectEdit->setWhatsThis(i18nc("@info:whatsthis", "Enter the email subject."));
+	connect(mEmailSubjectEdit, SIGNAL(textChanged(const QString&)), SLOT(contentsChanged()));
 	grid->addWidget(mEmailSubjectEdit, 2, 1, 1, 2);
 
 	// Email body
 	mEmailMessageEdit = new TextEdit(parent);
 	mEmailMessageEdit->setWhatsThis(i18nc("@info:whatsthis", "Enter the email message."));
+	connect(mEmailMessageEdit, SIGNAL(textChanged()), SLOT(contentsChanged()));
 	frameLayout->addWidget(mEmailMessageEdit);
 
 	// Email attachments
@@ -1128,6 +1189,7 @@ void EditEmailAlarmDlg::type_init(QWidget* parent, QVBoxLayout* frameLayout)
 	mEmailBcc = new CheckBox(i18n_chk_CopyEmailToSelf(), parent);
 	mEmailBcc->setFixedSize(mEmailBcc->sizeHint());
 	mEmailBcc->setWhatsThis(i18nc("@info:whatsthis", "If checked, the email will be blind copied to you."));
+	connect(mEmailBcc, SIGNAL(toggled(bool)), SLOT(contentsChanged()));
 	grid->addWidget(mEmailBcc, 1, 0, 1, 2, Qt::AlignLeft);
 }
 
@@ -1151,6 +1213,14 @@ void EditEmailAlarmDlg::type_initValues(const KAEvent* event)
 		// Set the values to their defaults
 		mEmailBcc->setChecked(Preferences::defaultEmailBcc());
 	}
+	attachmentEnable();
+}
+
+/******************************************************************************
+* Enable/disable controls depending on whether any attachments are entered.
+*/
+void EditEmailAlarmDlg::attachmentEnable()
+{
 	bool enable = mEmailAttachList->count();
 	mEmailAttachList->setEnabled(enable);
 	if (mEmailRemoveButton)
@@ -1173,6 +1243,29 @@ void EditEmailAlarmDlg::setAction(KAEvent::Action action, const AlarmText& alarm
 		mEmailMessageEdit->setPlainText(alarmText.displayText());
 }
 
+/******************************************************************************
+* Initialise various values in the New Alarm dialogue.
+*/
+void EditEmailAlarmDlg::setEmailFields(uint fromID, const EmailAddressList& addresses,
+                                       const QString& subject, const QStringList& attachments)
+{
+	if (fromID)
+		mEmailFromList->setCurrentIdentity(fromID);
+	if (!addresses.isEmpty())
+		mEmailToEdit->setText(addresses.join(", "));
+	if (!subject.isEmpty())
+		mEmailSubjectEdit->setText(subject);
+	if (!attachments.isEmpty())
+	{
+		mEmailAttachList->addItems(attachments);
+		attachmentEnable();
+	}
+}
+void EditEmailAlarmDlg::setBcc(bool bcc)
+{
+	mEmailBcc->setChecked(bcc);
+}
+
 /******************************************************************************
 * Set the read-only status of all non-template controls.
 */
@@ -1311,11 +1404,14 @@ bool EditEmailAlarmDlg::type_validate(bool trial)
 void EditEmailAlarmDlg::type_trySuccessMessage(ShellProcess*, const QString&)
 {
 	QString msg;
+	QString to = mEmailAddresses.join("<nl/>");
+	to.replace('<', "&lt;");
+	to.replace('>', "&gt;");
 	if (mEmailBcc->isChecked())
-		msg = i18nc("@info", "Email sent to:<nl/>%1<nl/>Bcc: <email>%2</email>",
-		            mEmailAddresses.join("<nl/>"), Preferences::emailBccAddress());
+		msg = "<qt>" + i18nc("@info", "Email sent to:<nl/>%1<nl/>Bcc: <email>%2</email>",
+		            to, Preferences::emailBccAddress()) + "</qt>";
 	else
-		msg = i18nc("@info", "Email sent to:<nl/>%1", mEmailAddresses.join("<nl/>"));
+		msg = "<qt>" + i18nc("@info", "Email sent to:<nl/>%1", to) + "</qt>";
 	KMessageBox::information(this, msg);
 }
 
@@ -1348,6 +1444,7 @@ void EditEmailAlarmDlg::slotAddAttachment()
 		mEmailAttachList->setCurrentIndex(mEmailAttachList->count() - 1);   // select the new item
 		mEmailRemoveButton->setEnabled(true);
 		mEmailAttachList->setEnabled(true);
+		contentsChanged();
 	}
 }
 
@@ -1366,6 +1463,7 @@ void EditEmailAlarmDlg::slotRemoveAttachment()
 		mEmailRemoveButton->setEnabled(false);
 		mEmailAttachList->setEnabled(false);
 	}
+	contentsChanged();
 }
 
 /******************************************************************************
@@ -1391,16 +1489,19 @@ CommandEdit::CommandEdit(QWidget* parent)
 	vlayout->setSpacing(KDialog::spacingHint());
 	mTypeScript = new CheckBox(EditCommandAlarmDlg::i18n_chk_EnterScript(), this);
 	mTypeScript->setFixedSize(mTypeScript->sizeHint());
-	connect(mTypeScript, SIGNAL(toggled(bool)), SLOT(slotCmdScriptToggled(bool)));
 	mTypeScript->setWhatsThis(i18nc("@info:whatsthis", "Check to enter the contents of a script instead of a shell command line"));
+	connect(mTypeScript, SIGNAL(toggled(bool)), SLOT(slotCmdScriptToggled(bool)));
+	connect(mTypeScript, SIGNAL(toggled(bool)), SIGNAL(changed()));
 	vlayout->addWidget(mTypeScript, 0, Qt::AlignLeft);
 
 	mCommandEdit = new LineEdit(LineEdit::Url, this);
 	mCommandEdit->setWhatsThis(i18nc("@info:whatsthis", "Enter a shell command to execute."));
+	connect(mCommandEdit, SIGNAL(textChanged(const QString&)), SIGNAL(changed()));
 	vlayout->addWidget(mCommandEdit);
 
 	mScriptEdit = new TextEdit(this);
 	mScriptEdit->setWhatsThis(i18nc("@info:whatsthis", "Enter the contents of a script to execute"));
+	connect(mScriptEdit, SIGNAL(textChanged()), SIGNAL(changed()));
 	vlayout->addWidget(mScriptEdit);
 
 	slotCmdScriptToggled(mTypeScript->isChecked());
