@@ -116,6 +116,7 @@ KAlarmApp::KAlarmApp()
 	  mAlarmsEnabled(true),
 	  mSpeechEnabled(false)
 {
+	KGlobal::locale()->insertCatalog("libkdepim");
 	kDebug();
 #ifndef NDEBUG
 	KAlarm::setTestModeConditions();
@@ -127,7 +128,7 @@ KAlarmApp::KAlarmApp()
 	Preferences::self()->readConfig();
 	Preferences::setAutoStart(true);
 	Preferences::self()->writeConfig();
-	Preferences::connect(SIGNAL(startOfDayChanged(const QTime&, const QTime&)), this, SLOT(changeStartOfDay()));
+	Preferences::connect(SIGNAL(startOfDayChanged(const QTime&)), this, SLOT(changeStartOfDay()));
 	Preferences::connect(SIGNAL(feb29TypeChanged(Feb29Type)), this, SLOT(slotFeb29TypeChanged(Feb29Type)));
 	Preferences::connect(SIGNAL(showInSystemTrayChanged(bool)), this, SLOT(slotShowInSystemTrayChanged()));
 	Preferences::connect(SIGNAL(archivedKeepDaysChanged(int)), this, SLOT(setArchivePurgeDays()));
@@ -142,10 +143,7 @@ KAlarmApp::KAlarmApp()
 		KConfigGroup config(KGlobal::config(), "General");
 		mNoSystemTray        = config.readEntry("NoSystemTray", false);
 		mOldShowInSystemTray = wantShowInSystemTray();
-		mStartOfDay          = Preferences::startOfDay();
-		if (Preferences::hasStartOfDayChanged())
-			mStartOfDay.setHMS(100,0,0);    // start of day time has changed: flag it as invalid
-		DateTime::setStartOfDay(mStartOfDay);
+		DateTime::setStartOfDay(Preferences::startOfDay());
 		mPrefsArchivedColour = Preferences::archivedColour();
 	}
 
@@ -205,6 +203,11 @@ bool KAlarmApp::restoreSession()
 	// Process is being restored by session management.
 	kDebug() << "Restoring";
 	++mActiveCount;
+	// Create the session config object now.
+	// This is necessary since if initCheck() below causes calendars to be updated,
+	// the session config created after that points to an invalid file, resulting
+	// in no windows being restored followed by a later crash.
+	kapp->sessionConfig();
 	if (!initCheck(true))     // open the calendar file (needed for main windows), don't process queue yet
 	{
 		--mActiveCount;
@@ -831,13 +834,8 @@ void KAlarmApp::slotShowInSystemTrayChanged()
 */
 void KAlarmApp::changeStartOfDay()
 {
-	QTime sod = Preferences::startOfDay();
-	DateTime::setStartOfDay(sod);
-	AlarmCalendar* cal = AlarmCalendar::resources();
-	if (KAEvent::adjustStartOfDay(cal->kcalEvents(KCalEvent::ACTIVE)))
-		cal->save();
-	Preferences::updateStartOfDayCheck(sod);  // now that calendar is updated, set OK flag in config file
-	mStartOfDay = sod;
+	DateTime::setStartOfDay(Preferences::startOfDay());
+	AlarmCalendar::resources()->adjustStartOfDay();
 }
 
 /******************************************************************************
@@ -1846,8 +1844,6 @@ bool KAlarmApp::initCheck(bool calendarOnly)
 	if (firstTime)
 	{
 		kDebug() << "first time";
-		if (!mStartOfDay.isValid())
-			changeStartOfDay();     // start of day time has changed, so adjust date-only alarms
 
 		/* Need to open the display calendar now, since otherwise if display
 		 * alarms are immediately due, they will often be processed while
