@@ -1,7 +1,7 @@
 /*
  *  spinbox.h  -  spin box with shift-click step value and read-only option
  *  Program:  kalarm
- *  Copyright © 2002-2006 by David Jarvie <software@astrojar.org.uk>
+ *  Copyright © 2002-2008 by David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,9 @@
 #ifndef SPINBOX_H
 #define SPINBOX_H
 
-#include <qspinbox.h>
+#include <QSpinBox>
+class QEvent;
+class QStyleOptionSpinBox;
 
 
 /**
@@ -45,17 +47,14 @@ class SpinBox : public QSpinBox
 	public:
 		/** Constructor.
 		 *  @param parent The parent object of this widget.
-		 *  @param name The name of this widget.
 		 */
-		explicit SpinBox(QWidget* parent = 0, const char* name = 0);
+		explicit SpinBox(QWidget* parent = 0);
 		/** Constructor.
 		 *  @param minValue The minimum value which the spin box can have.
 		 *  @param maxValue The maximum value which the spin box can have.
-		 *  @param step The (unshifted) step interval.
 		 *  @param parent The parent object of this widget.
-		 *  @param name The name of this widget.
 		 */
-		SpinBox(int minValue, int maxValue, int step = 1, QWidget* parent = 0, const char* name = 0);
+		SpinBox(int minValue, int maxValue, QWidget* parent = 0);
 		/** Returns true if the widget is read only. */
 		bool         isReadOnly() const                    { return mReadOnly; }
 		/** Sets whether the spin box can be changed by the user.
@@ -69,38 +68,48 @@ class SpinBox : public QSpinBox
 		/** Adds a value to the current value of the spin box. */
 		void         addValue(int change)                  { addValue(change, false); }
 		/** Returns the minimum value of the spin box. */
-		int          minValue() const                      { return mMinValue; }
+		int          minimum() const                       { return mMinValue; }
 		/** Returns the maximum value of the spin box. */
-		int          maxValue() const                      { return mMaxValue; }
+		int          maximum() const                       { return mMaxValue; }
 		/** Sets the minimum value of the spin box. */
-		void         setMinValue(int val);
+		void         setMinimum(int val);
 		/** Sets the maximum value of the spin box. */
-		void         setMaxValue(int val);
+		void         setMaximum(int val);
 		/** Sets the minimum and maximum values of the spin box. */
-		void         setRange(int minValue, int maxValue)  { setMinValue(minValue);  setMaxValue(maxValue); }
+		void         setRange(int minValue, int maxValue)  { setMinimum(minValue);  setMaximum(maxValue); }
 		/** Returns the specified value clamped to the range of the spin box. */
 		int          bound(int val) const;
+		/** Called whenever the user triggers a step, to adjust the value of
+		 *  the spin box by the unshifted increment.
+		 */
+		virtual void stepBy(int steps);
 		/** Returns the unshifted step increment, i.e. the amount by which the spin box value
 		 *  changes when a spin button is clicked without the shift key being pressed.
 		 */
-		int          lineStep() const                      { return mLineStep; }
+		int          singleStep() const                    { return mLineStep; }
 		/** Sets the unshifted step increment, i.e. the amount by which the spin box value
 		 *  changes when a spin button is clicked without the shift key being pressed.
 		 */
-		void         setLineStep(int step);
+		void         setSingleStep(int step);
 		/** Returns the shifted step increment, i.e. the amount by which the spin box value
 		 *  changes when a spin button is clicked while the shift key is pressed.
 		 */
-		int          lineShiftStep() const                 { return mLineShiftStep; }
+		int          singleShiftStep() const               { return mLineShiftStep; }
 		/** Sets the shifted step increment, i.e. the amount by which the spin box value
 		 *  changes when a spin button is clicked while the shift key is pressed.
 		 */
-		void         setLineShiftStep(int step);
-	public slots:
-		/** Increments the value of the spin box by the unshifted step increment. */
-		virtual void stepUp();
-		/** Decrements the value of the spin box by the unshifted step increment. */
-		virtual void stepDown();
+		void         setSingleShiftStep(int step);
+		/** Returns the rectangle containing the up arrow. */
+		QRect        upRect() const;
+		/** Returns the rectangle containing the down arrow. */
+		QRect        downRect() const;
+		/** Returns the rectangle containing the up and down arrows. */
+		QRect        upDownRect() const;
+		/** Sets whether the edit field is displayed. */
+		void         setUpDownOnly(bool only)              { mUpDownOnly = only; }
+		/** Initialise a QStyleOptionSpinBox with this instance's details. */
+		void         initStyleOption(QStyleOptionSpinBox&) const;
+
 	signals:
 		/** Signal emitted when the spin box's value is stepped (by the shifted or unshifted increment).
 		 *  @param step The requested step in the spin box's value. Note that the actual change in value
@@ -109,8 +118,6 @@ class SpinBox : public QSpinBox
 		void         stepped(int step);
 
 	protected:
-		/** A virtual method called whenever the value of the spin box has changed. */
-		virtual void valueChange();
 		/** Returns the initial adjustment to the value for a shift step up or down.
 		 * The default is to step up or down to the nearest multiple of the shift
 		 * increment, so the adjustment returned is for stepping up the decrement
@@ -124,18 +131,27 @@ class SpinBox : public QSpinBox
 		virtual int  shiftStepAdjustment(int oldValue, int shiftStep);
 		/** Receives events destined for the spin widget or for the edit field. */
 		virtual bool eventFilter(QObject*, QEvent*);
-		/** Updates the contents of the embedded QLineEdit to reflect the current value
-		 *  using mapValueToText(). Also enables/disables the up/down push buttons accordingly.
-		 */
-		virtual void updateDisplay();
+
+		virtual void paintEvent(QPaintEvent*);
+		virtual void focusOutEvent(QFocusEvent*);
+		virtual void mousePressEvent(QMouseEvent*);
+		virtual void mouseDoubleClickEvent(QMouseEvent*);
+		virtual void mouseReleaseEvent(QMouseEvent*);
+		virtual void mouseMoveEvent(QMouseEvent*);
+		virtual void keyPressEvent(QKeyEvent*); 
+		virtual void keyReleaseEvent(QKeyEvent*);
+		virtual void wheelEvent(QWheelEvent*);
 
 	private slots:
 		void         textEdited();
+		void         valueChange();
 	private:
 		void         init();
 		void         addValue(int change, bool current);
 		int          whichButton(const QPoint&);
-		bool         setShiftStepping(bool);
+		bool         setShiftStepping(bool, int currentButton);
+		bool         clickEvent(QMouseEvent*);
+		bool         keyEvent(QKeyEvent*);
 
 		enum { NO_BUTTON, UP, DOWN };
 
@@ -148,6 +164,7 @@ class SpinBox : public QSpinBox
 		bool         mShiftMinBound;    // true if a temporary minimum bound has been set during shift stepping
 		bool         mShiftMaxBound;    // true if a temporary maximum bound has been set during shift stepping
 		bool         mSelectOnStep;     // select the editor text whenever spin buttons are clicked (default)
+		bool         mUpDownOnly;       // true if edit field isn't displayed
 		bool         mReadOnly;         // value cannot be changed
 		bool         mSuppressSignals;
 		bool         mEdited;           // text field has been edited
