@@ -32,18 +32,18 @@ class KitchenSyncPart: public KParts::ReadOnlyPart
   Q_OBJECT
 
   public:
-    KitchenSyncPart( QWidget *parentWidget, const char *widgetName,
-                     QObject *parent, const char *name, const QStringList& );
+    KitchenSyncPart( QWidget *parentWidget, QObject *parent,
+                     const QVariantList &list );
     virtual ~KitchenSyncPart();
 
     static KAboutData *createAboutData();
 
     virtual void exit();
-    virtual bool openURL( const KURL &url );
+    virtual bool openUrl( const KUrl &url );
 
   protected:
     virtual bool openFile();
-    virtual void guiActivateEvent( KParts::GUIActivateEvent* );
+    virtual void guiActivateEvent( KParts::GUIActivateEvent *ev );
 };
 
 #endif
