@@ -32,12 +32,6 @@
 
 #include <config-kleopatra.h>
 
-#ifdef QT_NO_STL
-#undef QT_NO_STL
-#undef QT_STL
-#define QT_STL
-#endif
-
 #include "resolverecipientspage.h"
 #include "resolverecipientspage_p.h"
 
@@ -453,7 +447,7 @@ void ResolveRecipientsPage::Private::completeChangedInternal()
     const std::vector<Key> keys = q->resolvedCertificates();
     const bool haveSecret = std::find_if( keys.begin(), keys.end(), bind( &Key::hasSecret, _1 ) ) != keys.end();
     if ( isComplete && !haveSecret )
-        q->setExplanation( i18n( "<b>Warning:</b> None of the selected certificates seems to be your own certificate. You will not be able to decrypt the encrypted data again." ) );
+        q->setExplanation( i18n( "<b>Warning:</b> None of the selected certificates seem to be your own. You will not be able to decrypt the encrypted data again." ) );
     else
         q->setExplanation( QString() );
 }
@@ -608,10 +602,20 @@ void ResolveRecipientsPage::setAdditionalRecipientsInfo( const std::vector<Key>
     d->m_additionalRecipientsLabel->setText( i18n( "<qt><p>Recipients predefined via GnuPG settings:</p>%1", listKeysForInfo( recipients ) ) );
 }
 
-void ResolveRecipientsPage::setRecipients( const std::vector<Mailbox>& recipients )
+void ResolveRecipientsPage::setRecipients( const std::vector<Mailbox>& recipients, const std::vector<Mailbox> & encryptToSelfRecipients )
 {
     uint cmsCount = 0;
     uint pgpCount = 0;
+    uint senders = 0;
+    Q_FOREACH( const Mailbox & mb, encryptToSelfRecipients ) {
+        const QString id = "sender-" + QString::number( ++senders );
+        d->m_listWidget->addEntry( id, i18n("Sender"), mb );
+        const std::vector<Key> pgp = makeSuggestions( d->m_recipientPreferences, mb, OpenPGP );
+        const std::vector<Key> cms = makeSuggestions( d->m_recipientPreferences, mb, CMS );
+        pgpCount += !pgp.empty();
+        cmsCount += !cms.empty();
+        d->m_listWidget->setCertificates( id, pgp, cms );
+    }
     Q_FOREACH( const Mailbox& i, recipients )
     {
         //TODO:
