@@ -33,6 +33,7 @@
 #include <config-kleopatra.h>
 
 #include "mainwindow.h"
+#include "aboutdata.h"
 
 #include "models/keylistmodel.h"
 #include "models/keylistsortfilterproxymodel.h"
@@ -70,6 +71,11 @@
 #include "utils/stl_util.h"
 #include "utils/action_data.h"
 #include "utils/classify.h"
+#include "utils/filedialog.h"
+
+// from libkdepim
+#include "statusbarprogresswidget.h"
+#include "progressdialog.h"
 
 #include <KActionCollection>
 #include <KLocale>
@@ -84,6 +90,7 @@
 #include <KShortcutsDialog>
 #include <KXMLGUIFactory>
 #include <KEditToolBar>
+#include <KAboutApplicationDialog>
 #include <kdebug.h>
 
 #include <QAbstractItemView>
@@ -91,7 +98,6 @@
 #include <QFileDialog>
 #include <QToolBar>
 #include <QWidgetAction>
-#include <QProgressBar>
 #include <QApplication>
 #include <QCloseEvent>
 #include <QMenu>
@@ -120,17 +126,12 @@ using namespace boost;
 using namespace GpgME;
 
 namespace {
-    class ProgressBar : public QProgressBar {
-        Q_OBJECT
-    public:
-        explicit ProgressBar( QWidget * p=0 ) : QProgressBar( p ) {}
 
-    public Q_SLOTS:
-        void setProgress( int current, int total ) {
-            setRange( 0, total );
-            setValue( current );
-        }
-    };
+    static const KAboutData * aboutGpg4WinData() {
+        static const AboutGpg4WinData data;
+        return &data;
+    }
+
 }
 
 static KGuiItem KStandardGuiItem_quit() {
@@ -176,14 +177,14 @@ public:
         const int rc = KMessageBox::questionYesNoCancel( q,
                                                          i18n("%1 may be used by other applications as a service.\n"
                                                               "You may instead want to close this window without exiting %1.", app ),
-                                                         i18n("Really Quit?"), KStandardGuiItem_quit(), KStandardGuiItem_close(), KStandardGuiItem::cancel(),
+                                                         i18n("Really Quit?"), KStandardGuiItem_close(), KStandardGuiItem_quit(), KStandardGuiItem::cancel(),
                                                          "really-quit-" + app.toLower() );
         if ( rc == KMessageBox::Cancel )
             return;
         if ( !q->close() )
             return;
         // WARNING: 'this' might be deleted at this point!
-        if ( rc == KMessageBox::Yes )
+        if ( rc == KMessageBox::No )
             qApp->quit();
     }
     void certificateDetails() {
@@ -271,14 +272,14 @@ public:
     void gnupgLogViewer() {
         if( !QProcess::startDetached("kwatchgnupg" ) )
             KMessageBox::error( q, i18n( "Could not start the GnuPG Log Viewer (kwatchgnupg). "
-                                         "Please check your installation!" ),
+                                         "Please check your installation." ),
                                 i18n( "Error Starting KWatchGnuPG" ) );
     }
 
     void gnupgAdministrativeConsole() {
         if( !QProcess::startDetached("kgpgconf" ) )
             KMessageBox::error( q, i18n( "Could not start the GnuPG Administrative Console (kgpgconf). "
-                                         "Please check your installation!" ),
+                                         "Please check your installation." ),
                                 i18n( "Error Starting KGpgConf" ) );
     }
 
@@ -290,6 +291,10 @@ public:
             kDebug() << "no \"listview_popup\" <Menu> in kleopatra's ui.rc file";
     }
 
+    void aboutGpg4Win() {
+        ( new KAboutApplicationDialog( aboutGpg4WinData(), q ) )->show();
+    }
+
 private:
     void setupActions();
 
@@ -311,19 +316,21 @@ private:
     struct UI {
 
         TabWidget tabWidget;
-	ProgressBar progressBar;
 
 	explicit UI( MainWindow * q )
-	    : tabWidget( q ),
-	      progressBar( q->statusBar() )
+	    : tabWidget( q )
 	{
 	    KDAB_SET_OBJECT_NAME( tabWidget );
-	    KDAB_SET_OBJECT_NAME( progressBar );
 
-            progressBar.setFixedSize( progressBar.sizeHint() );
-
-            q->setCentralWidget( &tabWidget );
-            q->statusBar()->addPermanentWidget( &progressBar );
+	    q->setCentralWidget(&tabWidget);
+	    KPIM::ProgressDialog * progressDialog = new KPIM::ProgressDialog( q->statusBar(), q );
+	    KDAB_SET_OBJECT_NAME( progressDialog );
+	    progressDialog->hide();
+	    KPIM::StatusbarProgressWidget * statusBarProgressWidget 
+		    = new KPIM::StatusbarProgressWidget( progressDialog, q->statusBar() );
+	    KDAB_SET_OBJECT_NAME( statusBarProgressWidget );
+	    q->statusBar()->addPermanentWidget( statusBarProgressWidget, 0 );
+	    statusBarProgressWidget->show();
 	}
     } ui;
 };
@@ -349,7 +356,6 @@ MainWindow::Private::Private( MainWindow * qq )
 
     setupActions();
 
-    connect( &controller, SIGNAL(progress(int,int)), &ui.progressBar, SLOT(setProgress(int,int)) );
     connect( &controller, SIGNAL(message(QString,int)),  q->statusBar(), SLOT(showMessage(QString,int)) );
     connect( &controller, SIGNAL(contextMenuRequested(QAbstractItemView*,QPoint)),
              q, SLOT(slotContextMenuRequested(QAbstractItemView*,QPoint)) );
@@ -434,21 +440,26 @@ void MainWindow::Private::setupActions() {
           "view-refresh", q, SLOT(refreshX509Certificates()), QString(), false, true },
         { "tools_refresh_openpgp_certificates", i18n("Refresh OpenPGP Certificates"), QString(),
           "view-refresh", q, SLOT(refreshOpenPGPCertificates()), QString(), false, true },
-#ifndef ONLY_KLEO
+#ifndef KDEPIM_ONLY_KLEO
         { "crl_clear_crl_cache", i18n("Clear CRL Cache"), QString(),
           0, q, SLOT(clearCrlCache()), QString(), false, true },
         { "crl_dump_crl_cache", i18n("Dump CRL Cache"), QString(),
           0, q, SLOT(dumpCrlCache()), QString(), false, true },
-#endif // ONLY_KLEO
+#endif // KDEPIM_ONLY_KLEO
         { "crl_import_crl", i18n("Import CRL From File..."), QString(),
           0, q, SLOT(importCrlFromFile()), QString(), false, true },
+#if 0
         { "configure_backend", i18n("Configure GnuPG Backend..."), QString(),
           0, q, SLOT(configureBackend()), QString(), false, true },
+#endif
         // Settings menu
         { "settings_self_test", i18n("Perform Self-Test"), QString(),
           0, q, SLOT(selfTest()), QString(), false, true },
         // Window menu
         // (come from ui.tabWidget)
+        // Help menu
+        { "help_about_gpg4win", i18n("About Gpg4win"), QString(),
+          "gpg4win-compact", q, SLOT(aboutGpg4Win()), QString(), false, true },
     };
 
     make_actions_from_data( action_data, /*sizeof action_data / sizeof *action_data,*/ coll );
@@ -613,28 +624,40 @@ void MainWindow::dropEvent( QDropEvent * e ) {
 
     const QStringList files = extract_local_files( e->mimeData() );
 
-    // ### todo: classify further
+    const unsigned int classification = classify( files );
 
     QMenu menu;
+
     QAction * const signEncrypt = menu.addAction( i18n("Sign/Encrypt...") );
-    menu.addSeparator();
-    QAction * const importCerts = menu.addAction( i18n("Import Certificates") );
-    QAction * const importCRLs  = menu.addAction( i18n("Import CRLs") );
-    menu.addSeparator();
+    QAction * const decryptVerify = mayBeAnyMessageType( classification ) ? menu.addAction( i18n("Decrypt/Verify...") ) : 0 ;
+    if ( signEncrypt || decryptVerify )
+        menu.addSeparator();
+
+    QAction * const importCerts = mayBeAnyCertStoreType( classification ) ? menu.addAction( i18n("Import Certificates") ) : 0 ;
+    QAction * const importCRLs  = mayBeCertificateRevocationList( classification ) ? menu.addAction( i18n("Import CRLs") ) : 0 ;
+    if ( importCerts || importCRLs )
+        menu.addSeparator();
+
+    if ( !signEncrypt && !decryptVerify && !importCerts && !importCRLs )
+        return;
+
     menu.addAction( i18n("Cancel") );
 
     const QAction * const chosen = menu.exec( mapToGlobal( e->pos() ) );
 
+    if ( !chosen )
+        return;
+
     if ( chosen == signEncrypt )
         d->createAndStart<SignEncryptFilesCommand>( files );
+    else if ( chosen == decryptVerify )
+        d->createAndStart<DecryptVerifyFilesCommand>( files );
     else if ( chosen == importCerts )
         d->createAndStart<ImportCertificateFromFileCommand>( files );
     else if ( chosen == importCRLs )
         d->createAndStart<ImportCrlCommand>( files );
 
-    if ( chosen )
-        e->accept();
+    e->accept();
 }
 
-#include "mainwindow.moc"
 #include "moc_mainwindow.cpp"
