@@ -36,7 +36,6 @@
 #include "kmfiltermgr.h"
 #include "kmkernel.h"
 #include "folderselectiontreewidget.h"
-#include "kmfoldertree.h"
 #include "kmmainwin.h"
 #include "networkaccount.h"
 #include "folderrequester.h"
@@ -55,9 +54,7 @@
 #include <qdom.h>
 #include <QLabel>
 #include <QLayout>
-
-
-//Added by qt3to4:
+#include <QTimer>
 #include <QPixmap>
 #include <QGridLayout>
 #include <QHBoxLayout>
@@ -67,7 +64,7 @@
 using namespace KMail;
 
 AntiSpamWizard::AntiSpamWizard( WizardMode mode,
-                                QWidget* parent, KMFolderTree * mainFolderTree )
+                                QWidget* parent, MainFolderView * mainFolderTree )
   : KAssistantDialog( parent ),
     mInfoPage( 0 ),
     mSpamRulesPage( 0 ),
@@ -82,28 +79,28 @@ AntiSpamWizard::AntiSpamWizard( WizardMode mode,
 
 #ifndef NDEBUG
   if ( mMode == AntiSpam )
-    kDebug(5006) << endl <<"Considered anti-spam tools:";
+    kDebug() << endl <<"Considered anti-spam tools:";
   else
-    kDebug(5006) << endl <<"Considered anti-virus tools:";
+    kDebug() << endl <<"Considered anti-virus tools:";
 #endif
   for ( QList<SpamToolConfig>::Iterator it = mToolList.begin();
         it != mToolList.end(); ++it ) {
 #ifndef NDEBUG
-    kDebug(5006) <<"Predefined tool:" << (*it).getId();
-    kDebug(5006) <<"Config version:" << (*it).getVersion();
-    kDebug(5006) <<"Selection priority:" << (*it).getPrio();
-    kDebug(5006) <<"Displayed name:" << (*it).getVisibleName();
-    kDebug(5006) <<"Executable:" << (*it).getExecutable();
-    kDebug(5006) <<"WhatsThis URL:" << (*it).getWhatsThisText();
-    kDebug(5006) <<"Filter name:" << (*it).getFilterName();
-    kDebug(5006) <<"Detection command:" << (*it).getDetectCmd();
-    kDebug(5006) <<"Learn spam command:" << (*it).getSpamCmd();
-    kDebug(5006) <<"Learn ham command:" << (*it).getHamCmd();
-    kDebug(5006) <<"Detection header:" << (*it).getDetectionHeader();
-    kDebug(5006) <<"Detection pattern:" << (*it).getDetectionPattern();
-    kDebug(5006) <<"Use as RegExp:" << (*it).isUseRegExp();
-    kDebug(5006) <<"Supports Bayes Filter:" << (*it).useBayesFilter();
-    kDebug(5006) <<"Type:" << (*it).getType();
+    kDebug() <<"Predefined tool:" << (*it).getId();
+    kDebug() <<"Config version:" << (*it).getVersion();
+    kDebug() <<"Selection priority:" << (*it).getPrio();
+    kDebug() <<"Displayed name:" << (*it).getVisibleName();
+    kDebug() <<"Executable:" << (*it).getExecutable();
+    kDebug() <<"WhatsThis URL:" << (*it).getWhatsThisText();
+    kDebug() <<"Filter name:" << (*it).getFilterName();
+    kDebug() <<"Detection command:" << (*it).getDetectCmd();
+    kDebug() <<"Learn spam command:" << (*it).getSpamCmd();
+    kDebug() <<"Learn ham command:" << (*it).getHamCmd();
+    kDebug() <<"Detection header:" << (*it).getDetectionHeader();
+    kDebug() <<"Detection pattern:" << (*it).getDetectionPattern();
+    kDebug() <<"Use as RegExp:" << (*it).isUseRegExp();
+    kDebug() <<"Supports Bayes Filter:" << (*it).useBayesFilter();
+    kDebug() <<"Type:" << (*it).getType();
 #endif
   }
 
@@ -145,13 +142,13 @@ AntiSpamWizard::AntiSpamWizard( WizardMode mode,
 void AntiSpamWizard::accept()
 {
   if ( mSpamRulesPage ) {
-    kDebug( 5006 ) <<"Folder name for messages classified as spam is"
+    kDebug() <<"Folder name for messages classified as spam is"
                     << mSpamRulesPage->selectedSpamFolderName();
-    kDebug( 5006 ) <<"Folder name for messages classified as unsure is"
+    kDebug() <<"Folder name for messages classified as unsure is"
                     << mSpamRulesPage->selectedUnsureFolderName();
   }
   if ( mVirusRulesPage )
-    kDebug( 5006 ) <<"Folder name for viruses is"
+    kDebug() <<"Folder name for viruses is"
                     << mVirusRulesPage->selectedFolderName();
 
   KMFilterActionDict dict;
@@ -455,7 +452,7 @@ void AntiSpamWizard::accept()
     KMKernel::self()->filterMgr()->appendFilters(
           filterList, replaceExistingFilters );
 
-  QDialog::accept();
+  KDialog::accept();
 }
 
 
@@ -512,11 +509,13 @@ void AntiSpamWizard::checkToolAvailability()
     if ( (*it).isSpamTool() && (*it).isServerBased() ) {
       // check the configured account for pattern in <server>
       QString pattern = (*it).getServerPattern();
-      kDebug(5006) <<"Testing for server pattern:" << pattern;
+      kDebug() <<"Testing for server pattern:" << pattern;
 
       AccountManager* mgr = kmkernel->acctMgr();
-      KMAccount* account = mgr->first();
-      while ( account ) {
+      QList<KMAccount*>::iterator accountIt = mgr->begin();
+      while ( accountIt != mgr->end() ) {
+        KMAccount *account = *accountIt;
+        ++accountIt;
         if ( account->type() == KAccount::Pop ||
              account->type() == KAccount::Imap ||
              account->type() == KAccount::DImap ) {
@@ -526,7 +525,6 @@ void AntiSpamWizard::checkToolAvailability()
             found = true;
           }
         }
-        account = mgr->next();
       }
     }
     else {
@@ -570,16 +568,24 @@ void AntiSpamWizard::slotBuildSummary()
     text = ""; // TODO add summary for the virus part
   }
   else { // AntiSpam mode
-    if ( mSpamRulesPage->markAsReadSelected() )
-      text = i18n( "<p>Messages classified as spam are marked as read." );
-    else
-      text = i18n( "<p>Messages classified as spam are not marked as read." );
-
-    if ( mSpamRulesPage->moveSpamSelected() )
-      text += i18n( "<br />Spam messages are moved into the folder named <i>" )
-            + mSpamRulesPage->selectedSpamFolderName() + "</i>.</p>";
-    else
-      text += i18n( "<br />Spam messages are not moved into a certain folder.</p>" );
+    if ( mSpamRulesPage->markAsReadSelected() ) {
+      if ( mSpamRulesPage->moveSpamSelected() )
+        text = i18n( "<p>Messages classified as spam are marked as read."
+                     "<br />Spam messages are moved into the folder named <i>%1</i>.</p>"
+                     , mSpamRulesPage->selectedSpamFolderName() );
+      else
+        text = i18n( "<p>Messages classified as spam are marked as read."
+                     "<br />Spam messages are not moved into a certain folder.</p>" );
+    }
+    else {
+      if ( mSpamRulesPage->moveSpamSelected() )
+        text = i18n( "<p>Messages classified as spam are not marked as read."
+                     "<br />Spam messages are moved into the folder named <i>%1</i>.</p>"
+                     , mSpamRulesPage->selectedSpamFolderName() );
+      else
+        text = i18n( "<p>Messages classified as spam are not marked as read."
+                     "<br />Spam messages are not moved into a certain folder.</p>" );
+    }
 
     for ( QList<SpamToolConfig>::Iterator it = mToolList.begin();
           it != mToolList.end(); ++it ) {
@@ -603,8 +609,8 @@ void AntiSpamWizard::slotBuildSummary()
       if ( atLeastOneUnsurePattern ) {
         sortFilterOnExistance( i18n( "Semi spam (unsure) handling" ),
                                newFilters, replaceFilters );
-        text += i18n( "<p>The folder for messages classified as unsure (probably spam) is <i>" )
-              + mSpamRulesPage->selectedUnsureFolderName() + "</i>.</p>";
+        text += i18n( "<p>The folder for messages classified as unsure (probably spam) is <i>%1</i>.</p>"
+          , mSpamRulesPage->selectedUnsureFolderName() );
       }
     }
 
@@ -616,11 +622,11 @@ void AntiSpamWizard::slotBuildSummary()
 
     // Show the filters in the summary
     if ( !newFilters.isEmpty() )
-      text += i18n( "<p>The wizard will create the following filters:<ul>" )
-            + newFilters + "</ul></p>";
+      text += i18n( "<p>The wizard will create the following filters:<ul>%1</ul></p>"
+                , newFilters );
     if ( !replaceFilters.isEmpty() )
-      text += i18n( "<p>The wizard will replace the following filters:<ul>" )
-            + replaceFilters + "</ul></p>";
+      text += i18n( "<p>The wizard will replace the following filters:<ul>%1</ul></p>"
+                , replaceFilters );
   }
 
   mSummaryPage->setSummaryText( text );
@@ -629,7 +635,7 @@ void AntiSpamWizard::slotBuildSummary()
 
 int AntiSpamWizard::checkForProgram( const QString &executable )
 {
-  kDebug(5006) <<"Testing for executable:" << executable;
+  kDebug() <<"Testing for executable:" << executable;
   KProcess process;
   process.setShellCommand( executable );
   return process.execute ();
@@ -748,8 +754,8 @@ AntiSpamWizard::SpamToolConfig
   QString id = configGroup.readEntry( "Ident" );
   int version = configGroup.readEntry( "Version", 0 );
 #ifndef NDEBUG
-  kDebug(5006) <<"Found predefined tool:" << id;
-  kDebug(5006) <<"With config version  :" << version;
+  kDebug() <<"Found predefined tool:" << id;
+  kDebug() <<"With config version  :" << version;
 #endif
   int prio = configGroup.readEntry( "Priority", 1 );
   QString name = configGroup.readEntry( "VisibleName" );
@@ -796,8 +802,8 @@ void AntiSpamWizard::ConfigReader::mergeToolConfig( AntiSpamWizard::SpamToolConf
   for ( QList<SpamToolConfig>::Iterator it = mToolList.begin();
         it != mToolList.end(); ++it ) {
 #ifndef NDEBUG
-    kDebug(5006) <<"Check against tool:" << (*it).getId();
-    kDebug(5006) <<"Against version   :" << (*it).getVersion();
+    kDebug() <<"Check against tool:" << (*it).getId();
+    kDebug() <<"Against version   :" << (*it).getVersion();
 #endif
     if ( (*it).getId() == config.getId() )
     {
@@ -805,7 +811,7 @@ void AntiSpamWizard::ConfigReader::mergeToolConfig( AntiSpamWizard::SpamToolConf
       if ( (*it).getVersion() < config.getVersion() )
       {
 #ifndef NDEBUG
-        kDebug(5006) <<"Replacing config ...";
+        kDebug() <<"Replacing config ...";
 #endif
         mToolList.erase( it );
         mToolList.append( config );
@@ -862,9 +868,8 @@ ASWizPage::ASWizPage( QWidget * parent, const char * name,
   mLayout->addItem( sideLayout );
   mLayout->addItem( new QSpacerItem( 5, 5, QSizePolicy::Minimum, QSizePolicy::Expanding ) );
 
-  mPixmap = new QPixmap( UserIcon(banner) );
   mBannerLabel = new QLabel( this );
-  mBannerLabel->setPixmap( *mPixmap );
+  mBannerLabel->setPixmap( UserIcon(banner) );
   mBannerLabel->setScaledContents( false );
   mBannerLabel->setFrameShape( QFrame::StyledPanel );
   mBannerLabel->setFrameShadow( QFrame::Sunken );
@@ -968,7 +973,7 @@ void ASWizInfoPage::processSelectionChange()
 
 //---------------------------------------------------------------------------
 ASWizSpamRulesPage::ASWizSpamRulesPage( QWidget * parent, const char * name,
-                                        KMFolderTree * mainFolderTree )
+                                        MainFolderView * mainFolderTree )
   : ASWizPage( parent, name )
 {
   QVBoxLayout *layout = new QVBoxLayout();
@@ -985,7 +990,8 @@ ASWizSpamRulesPage::ASWizSpamRulesPage( QWidget * parent, const char * name,
             "but you may change that in the folder view below.") );
   layout->addWidget( mMoveSpamRules );
 
-  mFolderReqForSpamFolder = new FolderRequester( this, mainFolderTree );
+  mFolderReqForSpamFolder = new FolderRequester( this );
+  mFolderReqForSpamFolder->setFolderTree( mainFolderTree );
   mFolderReqForSpamFolder->setFolder( "trash" );
   mFolderReqForSpamFolder->setMustBeReadWrite( true );
   mFolderReqForSpamFolder->setShowOutbox( false );
@@ -1004,7 +1010,8 @@ ASWizSpamRulesPage::ASWizSpamRulesPage( QWidget * parent, const char * name,
             "selected a capable tool, you cannot select a folder as well.</p>") );
   layout->addWidget( mMoveUnsureRules );
 
-  mFolderReqForUnsureFolder = new FolderRequester( this, mainFolderTree );
+  mFolderReqForUnsureFolder = new FolderRequester( this );
+  mFolderReqForUnsureFolder->setFolderTree( mainFolderTree );
   mFolderReqForUnsureFolder->setFolder( "inbox" );
   mFolderReqForUnsureFolder->setMustBeReadWrite( true );
   mFolderReqForUnsureFolder->setShowOutbox( false );
@@ -1094,7 +1101,7 @@ void ASWizSpamRulesPage::allowUnsureFolderSelection( bool enabled )
 
 //---------------------------------------------------------------------------
 ASWizVirusRulesPage::ASWizVirusRulesPage( QWidget * parent, const char * name,
-                                  KMFolderTree * mainFolderTree )
+                                  MainFolderView * mainFolderTree )
   : ASWizPage( parent, name )
 {
   QGridLayout *grid = new QGridLayout();
