@@ -159,7 +159,7 @@ void KMAcctImap::killAllJobs( bool disconnectSlave )
     for ( ; it2 != msgList.end(); ++it2 ) {
        KMMessage *msg = *it2;
        if ( msg->transferInProgress() ) {
-          kDebug(5006) << "Resetting mail";
+          kDebug() << "Resetting mail";
           msg->setTransferInProgress( false );
        }
     }
@@ -275,7 +275,7 @@ void KMAcctImap::cancelMailCheck()
 //-----------------------------------------------------------------------------
 void KMAcctImap::processNewMail(bool interactive)
 {
-  kDebug(5006) <<"processNewMail" << mCheckingSingleFolder <<",status="<<makeConnection();
+  kDebug() <<"processNewMail" << mCheckingSingleFolder <<",status="<<makeConnection();
   if ( !mFolder || !mFolder->folder() || !mFolder->folder()->child() ||
        makeConnection() == ImapAccountBase::Error ) {
     // checks for mCountRemainChecks
@@ -454,7 +454,7 @@ void KMAcctImap::postProcessNewMail( KMFolder * folder )
     if (idx != -1) {
 
       msg = folder->getMsg( idx );
-      if (!msg) { // sanity checking
+      if ( !msg ) {
         mFilterSerNumsToSave.remove( QString( "%1" ).arg( sernum ) );
         continue;
       }
@@ -506,7 +506,7 @@ void KMAcctImap::slotUpdateFolderList()
 {
   if ( !mFolder || !mFolder->folder() || !mFolder->folder()->child() )
   {
-    kWarning(5006) << "Return";
+    kWarning() << "Return";
     return;
   }
   QStringList strList;
@@ -565,7 +565,7 @@ ImapAccountBase::ConnectionState KMAcctImap::makeConnection()
 void KMAcctImap::slotResetConnectionError()
 {
   mSlaveConnectionError = false;
-  kDebug(5006) ;
+  kDebug() ;
 }
 
 void KMAcctImap::slotFolderSelected( KMFolderImap* folder, bool )
@@ -593,7 +593,16 @@ int KMAcctImap::slotFilterMsg( KMMessage *msg )
     // messageRetrieved(0) is always possible
     return -1;
   }
-  msg->setTransferInProgress(false);
+
+  msg->setTransferInProgress( false );
+
+  if ( msg->parent() && msg->parent()->find( msg ) == -1 ) {
+    // ### Isn't the msg pointer invalid already at this point, because it was removed
+    //     from the message list!? Seems to work, so...
+    kWarning() << "The message with subject" << msg->subject() << "was removed from the server"
+               << "while we were filtering!";
+    return 1; // Yay for clean return enums! (see kmfiltermgr for explaination)
+  }
   quint32 serNum = msg->getMsgSerNum();
   if ( serNum )
     mFilterSerNumsToSave.remove( QString( "%1" ).arg( serNum ) );
