@@ -26,7 +26,6 @@
 #define KMail_PART_H
 
 #include "kmail_export.h"
-#include <kdeversion.h>
 #include <kparts/browserextension.h>
 #include <kparts/statusbarextension.h>
 #include <kparts/factory.h>
@@ -43,10 +42,17 @@ class KMMainWidget;
 namespace KPIM { class StatusbarProgressWidget; }
 using KPIM::StatusbarProgressWidget;
 class KMFolder;
-class KMFolderTreeItem;
 
 class ActionManager;
 
+namespace KMail
+{
+  class FolderViewItem;
+}
+
+using namespace KMail; // Needed because moc is unable to properly map namespaces
+                       // in signal/slot parameters. No one includes this file anyway.
+
 class KMailPart: public KParts::ReadOnlyPart
 {
   Q_OBJECT
@@ -63,8 +69,8 @@ class KMailPart: public KParts::ReadOnlyPart
     Q_SCRIPTABLE void exit();
     void updateEditMenu() {}
     void exportFolder( KMFolder* folder );
-    void slotIconChanged( KMFolderTreeItem *fti );
-    void slotNameChanged( KMFolderTreeItem *fti );
+    void slotIconChanged( FolderViewItem *fti );
+    void slotNameChanged( FolderViewItem *fti );
 
   signals:
     void textChanged( const QString& );
