@@ -36,6 +36,7 @@
 #include <KMenu>
 #include <KMessageBox>
 #include <KPushButton>
+#include <KInputDialog>
 
 #include <QBuffer>
 #include <QClipboard>
@@ -145,6 +146,8 @@ void KMComposerEditor::replaceUnknownChars( const QTextCodec *codec )
 
 bool KMComposerEditor::canInsertFromMimeData( const QMimeData *source ) const
 {
+  if ( source->hasImage() && source->hasFormat( "image/png" ) )
+    return true;
   if ( KPIM::MailList::canDecode( source ) )
     return true;
   if ( source->hasFormat( "text/x-kmail-textsnippet" ) )
@@ -157,6 +160,32 @@ bool KMComposerEditor::canInsertFromMimeData( const QMimeData *source ) const
 
 void KMComposerEditor::insertFromMimeData( const QMimeData *source )
 {
+  // If this is a PNG image, either add it as an attachment or as an inline image
+  if ( source->hasImage() && source->hasFormat( "image/png" ) ) {
+    if ( textMode() == KRichTextEdit::Rich ) {
+      // Let the textedit from kdepimlibs handle inline images
+      KPIMTextEdit::TextEdit::insertFromMimeData( source );
+      return;
+    }
+
+    // Get the image data before showing the dialog, since that processes events which can delete
+    // the QMimeData object behind our back
+    const QByteArray imageData = source->data( "image/png" );
+
+    // Ok, when we reached this point, the user wants to add the image as an attachment.
+    // Ask for the filename first.
+    bool ok;
+    const QString attName =
+       KInputDialog::getText( "KMail", i18n( "Name of the attachment:" ), QString(), &ok, this );
+    if ( !ok ) {
+      return;
+    }
+
+    m_composerWin->addAttachment( attName, "base64", imageData, "image", "png", QByteArray(),
+                                  QString(), QByteArray() );
+    return;
+  }
+
     // If this is a list of mails, attach those mails as forwards.
   if ( KPIM::MailList::canDecode( source ) ) {
 
@@ -212,7 +241,7 @@ void KMComposerEditor::insertFromMimeData( const QMimeData *source )
     return;
   }
 
-  KPIMTextEdit::TextEdit::insertFromMimeData(source);
+  KPIMTextEdit::TextEdit::insertFromMimeData( source );
 }
 
 #include "kmcomposereditor.moc"
