@@ -298,7 +298,7 @@ void KMMimePartTree::startHandleAttachmentCommand( int action )
     return;
 
   partNode *node = static_cast<KMMimePartTreeItem *>( selected.first() )->node();
-  QString name = mReaderWin->tempFileUrlFromPartNode( node ).path();
+  QString name = mReaderWin->tempFileUrlFromPartNode( node ).toLocalFile();
 
   mReaderWin->prepareHandleAttachment( node->nodeId(), name );
   mReaderWin->slotHandleAttachment( action );
@@ -435,7 +435,7 @@ void KMMimePartTreeItem::correctSize()
 void KMMimePartTreeItem::setIconAndTextForType( const QString & mime )
 {
   QString mimetype = mime.toLower();
-  if ( mimetype.startsWith( "multipart/" ) ) {
+  if ( mimetype.startsWith( QLatin1String("multipart/") ) ) {
     setText( columnType, mimetype );
     setIcon( columnDescription, QIcon( SmallIcon("folder") ) );
   } else if ( mimetype == "application/octet-stream" ) {
