@@ -1,6 +1,6 @@
 /*
     KNode, the KDE newsreader
-    Copyright (c) 2005-2006 Volker Krause <volker.krause@rwth-aachen.de>
+    Copyright (c) 2005-2006 Volker Krause <vkrause@kde.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -11,9 +11,6 @@
     Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, US
 */
 
-#include <unistd.h>
-#include <stdlib.h>
-#include <sys/stat.h>
 #include <QBuffer>
 #include <QClipboard>
 #include <QDir>
@@ -183,7 +180,7 @@ void ArticleWidget::initActions()
   connect(mFixedFontToggle, SIGNAL(triggered(bool) ), SLOT(slotToggleFixedFont()));
   mFixedFontToggle->setShortcut(QKeySequence(Qt::Key_X));
   mFancyToggle = mActionCollection->add<KToggleAction>("view_fancyFormating");
-  mFancyToggle->setText(i18n("Fancy Formating"));
+  mFancyToggle->setText(i18n("Fancy Formatting"));
   connect(mFancyToggle, SIGNAL(triggered(bool) ), SLOT(slotToggleFancyFormating()));
   mFancyToggle->setShortcut(QKeySequence(Qt::Key_Y));
   mRot13Toggle = mActionCollection->add<KToggleAction>("view_rot13");
@@ -338,6 +335,7 @@ void ArticleWidget::readConfig()
   mFancyToggle->setChecked( knGlobals.settings()->interpretFormatTags() );
 
   mShowHtml = knGlobals.settings()->alwaysShowHTML();
+  mViewer->setOnlyLocalReferences( !knGlobals.settings()->allowExternalReferences() );
 
   KConfigGroup conf(knGlobals.config(), "READNEWS" );
   mAttachmentStyle = conf.readEntry( "attachmentStyle", "inline" );
@@ -583,7 +581,7 @@ void ArticleWidget::displayErrorMessage( const QString &msg )
   mViewer->write( QString("<b><font size=\"+1\" color=\"red\">") );
   mViewer->write( i18n("An error occurred.") );
   mViewer->write( QString("</font></b><hr/><br/>") );
-  mViewer->write( errMsg.replace( "\n", "<br/>" ) );
+  mViewer->write( errMsg.replace( '\n', "<br/>" ) );
   mViewer->write( QString("</body></html>") );
   mViewer->end();
 
