@@ -24,44 +24,30 @@
 */
 
 #include "koeditordetails.h"
-#include "koprefs.h"
 #include "koglobals.h"
-#include "koeditorfreebusy.h"
-#include "kocore.h"
+#include "koprefs.h"
 
-#include <kcal/incidence.h>
-#include <kpimutils/email.h>
-
-#ifndef KORG_NOKABC
-#include <kabc/addresseedialog.h>
-#include <kabc/stdaddressbook.h>
-#include <libkdepim/addressesdialog.h>
-#include <libkdepim/addresseelineedit.h>
 #include <libkdepim/distributionlist.h>
-#endif
 #include <libkdepim/kvcarddrag.h>
 
-#include <KComboBox>
-#include <kdebug.h>
-#include <klocale.h>
-#include <kiconloader.h>
-#include <kmessagebox.h>
-#include <kvbox.h>
+#include <KABC/StdAddressBook>
+#include <KCal/Incidence>
+#include <KPIMUtils/Email>
 
+#include <KDebug>
+#include <KLocale>
+#include <KMessageBox>
+
+#include <QBoxLayout>
 #include <QCheckBox>
-#include <QDateTime>
-#include <QLabel>
-#include <QLayout>
-#include <QLineEdit>
+#include <QMimeData>
 #include <QPushButton>
-#include <QRadioButton>
-#include <QRegExp>
-#include <QGridLayout>
-#include <QDragMoveEvent>
-#include <QEvent>
-#include <QDropEvent>
 #include <QVBoxLayout>
+
+#ifndef KORG_NODND
 #include <QDragEnterEvent>
+#include <QDragMoveEvent>
+#endif
 
 template <>
 CustomListViewItem<KCal::Attendee *>::~CustomListViewItem()
@@ -101,34 +87,36 @@ KOAttendeeListView::~KOAttendeeListView()
 {
 }
 
+#ifndef KORG_NODND
 void KOAttendeeListView::contentsDragEnterEvent( QDragEnterEvent *e )
 {
-  dragEnterEvent(e);
+  dragEnterEvent( e );
 }
+#endif
 
+#ifndef KORG_NODND
 void KOAttendeeListView::contentsDragMoveEvent( QDragMoveEvent *e )
 {
-#ifndef KORG_NODND
   const QMimeData *md = e->mimeData();
   if ( KPIM::KVCardDrag::canDecode( md ) || md->hasText() ) {
     e->accept();
   } else {
     e->ignore();
   }
-#endif
 }
+#endif
 
+#ifndef KORG_NODND
 void KOAttendeeListView::dragEnterEvent( QDragEnterEvent *e )
 {
-#ifndef KORG_NODND
   const QMimeData *md = e->mimeData();
   if ( KPIM::KVCardDrag::canDecode( md ) || md->hasText() ) {
     e->accept();
   } else {
     e->ignore();
   }
-#endif
 }
+#endif
 
 void KOAttendeeListView::addAttendee( const QString &newAttendee )
 {
@@ -136,26 +124,29 @@ void KOAttendeeListView::addAttendee( const QString &newAttendee )
   QString name;
   QString email;
   KPIMUtils::extractEmailAddressAndName( newAttendee, email, name );
+#ifndef KORG_NODND
   emit dropped( new Attendee( name, email, true ) );
+#endif
 }
 
+#ifndef KORG_NODND
 void KOAttendeeListView::contentsDropEvent( QDropEvent *e )
 {
   dropEvent( e );
 }
+#endif
 
+#ifndef KORG_NODND
 void KOAttendeeListView::dropEvent( QDropEvent *e )
 {
-#ifndef KORG_NODND
   const QMimeData *md = e->mimeData();
 
-#ifndef KORG_NOKABC
   if ( KPIM::KVCardDrag::canDecode( md ) ) {
     KABC::Addressee::List list;
     KPIM::KVCardDrag::fromMimeData( md, list );
 
-    KABC::Addressee::List::Iterator it;
-    for ( it = list.begin(); it != list.end(); ++it ) {
+    KABC::Addressee::List::ConstIterator it;
+    for ( it = list.constBegin(); it != list.constEnd(); ++it ) {
       QString em( (*it).fullEmail() );
       if ( em.isEmpty() ) {
         em = (*it).realName();
@@ -163,7 +154,7 @@ void KOAttendeeListView::dropEvent( QDropEvent *e )
       addAttendee( em );
     }
   }
-#endif // KORG_NOKABC
+
   if ( md->hasText() ) {
     QString text = md->text();
     kDebug() << "Dropped :" << text;
@@ -172,8 +163,8 @@ void KOAttendeeListView::dropEvent( QDropEvent *e )
       addAttendee( *it );
     }
   }
-#endif //KORG_NODND
 }
+#endif
 
 KOEditorDetails::KOEditorDetails( int spacing, QWidget *parent )
   : KOAttendeeEditor( parent ), mDisableItemUpdate( false )
@@ -237,20 +228,23 @@ void KOEditorDetails::removeAttendee()
   }
 
   AttendeeListItem *nextSelectedItem = static_cast<AttendeeListItem*>( aItem->nextSibling() );
-  if( mListView->childCount() == 1 )
-      nextSelectedItem = 0;
-  if( mListView->childCount() > 1 && aItem == mListView->lastItem() )
-      nextSelectedItem = static_cast<AttendeeListItem*>(  mListView->firstChild() );
+  if ( mListView->childCount() == 1 ) {
+    nextSelectedItem = 0;
+  }
+  if ( mListView->childCount() > 1 && aItem == mListView->lastItem() ) {
+    nextSelectedItem = static_cast<AttendeeListItem*>( mListView->firstChild() );
+  }
 
   Attendee *delA = new Attendee( aItem->data()->name(), aItem->data()->email(),
                                  aItem->data()->RSVP(), aItem->data()->status(),
                                  aItem->data()->role(), aItem->data()->uid() );
-  mdelAttendees.append( delA );
+  mDelAttendees.append( delA );
 
   delete aItem;
 
-  if( nextSelectedItem )
-      mListView->setSelected( nextSelectedItem, true );
+  if ( nextSelectedItem ) {
+    mListView->setSelected( nextSelectedItem, true );
+  }
   updateAttendeeInput();
   emit updateAttendeeSummary( mListView->childCount() );
 }
@@ -281,7 +275,7 @@ void KOEditorDetails::readIncidence( Incidence *event )
   emit updateAttendeeSummary( mListView->childCount() );
 }
 
-void KOEditorDetails::writeIncidence( Incidence *incidence )
+void KOEditorDetails::fillIncidence( Incidence *incidence )
 {
   incidence->clearAttendees();
   QVector<Q3ListViewItem*> toBeDeleted;
@@ -309,7 +303,7 @@ void KOEditorDetails::writeIncidence( Incidence *incidence )
       }
     } else {
       bool skip = false;
-      if ( attendee->email().endsWith( "example.net" ) ) {
+      if ( attendee->email().endsWith( QLatin1String( "example.net" ) ) ) {
         if ( KMessageBox::warningYesNo(
               this,
               i18nc( "@info",
@@ -326,7 +320,7 @@ void KOEditorDetails::writeIncidence( Incidence *incidence )
     }
   }
 
-  KOAttendeeEditor::writeIncidence( incidence );
+  KOAttendeeEditor::fillIncidence( incidence );
 
   // cleanup
   qDeleteAll( toBeDeleted );
@@ -376,14 +370,15 @@ void KOEditorDetails::changeStatusForMe( Attendee::PartStat status )
   }
 }
 
-Q3ListViewItem* KOEditorDetails::hasExampleAttendee() const
+Q3ListViewItem *KOEditorDetails::hasExampleAttendee() const
 {
   for ( Q3ListViewItemIterator it( mListView ); it.current(); ++it ) {
     AttendeeListItem *item = static_cast<AttendeeListItem*>( it.current() );
     Attendee *attendee = item->data();
     Q_ASSERT( attendee );
-    if ( isExampleAttendee( attendee ) )
-        return item;
+    if ( isExampleAttendee( attendee ) ) {
+      return item;
+    }
   }
   return 0;
 }
