@@ -26,27 +26,22 @@
 //krazy:excludeall=kdebug because we use the korgac(check) debug area in here
 
 #include "koalarmclient.h"
-#include "korgacadaptor.h"
-#include "alarmdockwindow.h"
 #include "alarmdialog.h"
+#include "alarmdockwindow.h"
+#include "korgacadaptor.h"
 
-#include <kcal/calendarresources.h>
+#include <KCal/CalendarResources>
+using namespace KCal;
 
-#include <kstandarddirs.h>
-#include <kdebug.h>
-#include <klocale.h>
-#include <kdatetime.h>
-#include <kapplication.h>
-#include <kwindowsystem.h>
-#include <kconfiggroup.h>
-#include <kglobal.h>
-
-#include <QPushButton>
-#include <QtDBus/QtDBus>
+#include <KApplication>
+#include <KConfig>
+#include <KConfigGroup>
+#include <KDebug>
+#include <KStandardDirs>
+#include <KSystemTimeZones>
 
 KOAlarmClient::KOAlarmClient( QObject *parent )
-  : QObject( parent ),
-    mDialog( 0 )
+  : QObject( parent ), mDocker( 0 ), mDialog( 0 )
 {
   new KOrgacAdaptor( this );
   QDBusConnection::sessionBus().registerObject( "/ac", this );
@@ -56,21 +51,17 @@ KOAlarmClient::KOAlarmClient( QObject *parent )
   KConfigGroup generalGroup( &korgConfig, "General" );
   bool showDock = generalGroup.readEntry( "ShowReminderDaemon", true );
 
-  mDocker = new AlarmDockWindow;
   if ( showDock ) {
-    mDocker->show();
-  } else {
-    mDocker->hide();
+    mDocker = new AlarmDockWindow;
+
+    connect( this, SIGNAL(reminderCount(int)), mDocker, SLOT(slotUpdate(int)) );
+    connect( mDocker, SIGNAL(quitSignal()), SLOT(slotQuit()) );
   }
 
-  connect( this, SIGNAL(reminderCount(int)), mDocker, SLOT(slotUpdate(int)) );
-  connect( mDocker, SIGNAL(quitSignal()), SLOT(slotQuit()) );
-
-  KConfigGroup timedateGroup( &korgConfig, "Time & Date" );
-  QString tz = timedateGroup.readEntry( "TimeZoneId" );
-  kDebug() << "TimeZone:" << tz;
-
-  mCalendar = new CalendarResources( tz );
+  const KTimeZone zone = KSystemTimeZones::local();
+  mCalendar = new CalendarResources( zone.isValid() ?
+                                     KDateTime::Spec( zone ) :
+                                     KDateTime::ClockTime );
   mCalendar->readConfig();
   mCalendar->load();
 
@@ -85,14 +76,13 @@ KOAlarmClient::KOAlarmClient( QObject *parent )
   KConfigGroup genGroup( KGlobal::config(), "General" );
   int numReminders = genGroup.readEntry( "Reminders", 0 );
   for ( int i=1; i<=numReminders; ++i ) {
-    QString group( QString( "Incidence-%1" ).arg( i ) );
-    KConfigGroup *incGroup = new KConfigGroup( KGlobal::config(), group );
-    QString uid = incGroup->readEntry( "UID" );
-    QDateTime dt = incGroup->readEntry( "RemindAt", QDateTime() );
+    const QString group( QString( "Incidence-%1" ).arg( i ) );
+    const KConfigGroup incGroup( KGlobal::config(), group );
+    const QString uid = incGroup.readEntry( "UID" );
+    const QDateTime dt = incGroup.readEntry( "RemindAt", QDateTime() );
     if ( !uid.isEmpty() ) {
-      createReminder( mCalendar->incidence( uid ), dt );
+      createReminder( mCalendar->incidence( uid ), dt, QString() );
     }
-    delete incGroup;
   }
   if ( numReminders ) {
      genGroup.writeEntry( "Reminders", 0 );
@@ -130,12 +120,13 @@ void KOAlarmClient::checkAlarms()
   for ( it = alarms.constBegin(); it != alarms.constEnd(); ++it ) {
     kDebug(5891) << "REMINDER:" << (*it)->parent()->summary();
     Incidence *incidence = mCalendar->incidence( (*it)->parent()->uid() );
-    createReminder( incidence, QDateTime::currentDateTime() );
+    createReminder( incidence, from, (*it)->text() );
   }
 }
 
 void KOAlarmClient::createReminder( KCal::Incidence *incidence,
-                                    const QDateTime &dt )
+                                    const QDateTime &dt,
+                                    const QString &displayText )
 {
   if ( !incidence ) {
     return;
@@ -143,13 +134,18 @@ void KOAlarmClient::createReminder( KCal::Incidence *incidence,
 
   if ( !mDialog ) {
     mDialog = new AlarmDialog();
-    connect( mDialog, SIGNAL(reminderCount(int)), mDocker, SLOT(slotUpdate(int)) );
-    connect( mDocker, SIGNAL(suspendAllSignal()), mDialog, SLOT(suspendAll()) );
-    connect( mDocker, SIGNAL(dismissAllSignal()), mDialog, SLOT(dismissAll()) );
     connect( this, SIGNAL(saveAllSignal()), mDialog, SLOT(slotSave()) );
+    if ( mDocker ) {
+      connect( mDialog, SIGNAL(reminderCount(int)),
+               mDocker, SLOT(slotUpdate(int)) );
+      connect( mDocker, SIGNAL(suspendAllSignal()),
+               mDialog, SLOT(suspendAll()) );
+      connect( mDocker, SIGNAL(dismissAllSignal()),
+               mDialog, SLOT(dismissAll()) );
+    }
   }
 
-  mDialog->addIncidence( incidence, dt );
+  mDialog->addIncidence( incidence, dt, displayText );
   mDialog->wakeUp();
   saveLastCheckTime();
 }
@@ -224,12 +220,27 @@ void KOAlarmClient::debugShowDialog()
 
 void KOAlarmClient::hide()
 {
-  mDocker->hide();
+  delete mDocker;
+  mDocker = 0;
 }
 
 void KOAlarmClient::show()
 {
-  mDocker->show();
+  if ( !mDocker ) {
+    mDocker = new AlarmDockWindow;
+
+    connect( this, SIGNAL(reminderCount(int)), mDocker, SLOT(slotUpdate(int)) );
+    connect( mDocker, SIGNAL(quitSignal()), SLOT(slotQuit()) );
+
+    if ( mDialog ) {
+      connect( mDialog, SIGNAL(reminderCount(int)),
+               mDocker, SLOT(slotUpdate(int)) );
+      connect( mDocker, SIGNAL(suspendAllSignal()),
+               mDialog, SLOT(suspendAll()) );
+      connect( mDocker, SIGNAL(dismissAllSignal()),
+               mDialog, SLOT(dismissAll()) );
+    }
+  }
 }
 
 #include "koalarmclient.moc"
