@@ -24,19 +24,22 @@
 #ifndef MAILSCHEDULER_H
 #define MAILSCHEDULER_H
 
+#include <KCal/Scheduler>
+
 #include <QList>
 #include <QMap>
 #include <QString>
 
-#include <kcal/imipscheduler.h>
-
 namespace KCal {
+  class Incidence;
+}
+using namespace KCal;
 
 /*
   This class implements the iTIP interface using the email interface specified
   as Mail.
 */
-class MailScheduler : public IMIPScheduler
+class MailScheduler : public Scheduler
 {
   public:
     explicit MailScheduler( Calendar * );
@@ -53,10 +56,11 @@ class MailScheduler : public IMIPScheduler
     /** Returns the directory where the free-busy information is stored */
     virtual QString freeBusyDir();
 
+    /** Accepts a counter proposal */
+    bool acceptCounterProposal( Incidence *incidence );
+
   private:
     QMap<IncidenceBase *, QString> mEventMap;
 };
 
-}
-
 #endif
