@@ -31,23 +31,19 @@
 #include "komessagebox.h"
 #include "incidencechanger.h"
 #include "kohelper.h"
-#include <korganizer/baseview.h>
+#include "korganizer/baseview.h"
 
-#include <kcal/event.h>
-#include <kcal/todo.h>
-#include <kcal/dndfactory.h>
-#include <kcal/icaldrag.h>
-#include <kcal/vcaldrag.h>
-#include <kcal/calendar.h>
-#include <kcal/calendarresources.h>
+#include <KCal/Calendar>
+#include <KCal/DndFactory>
+#include <KCal/ICalDrag>
+#include <KCal/Todo>
+#include <KCal/VCalDrag>
 
-#include <kdebug.h>
-#include <klocale.h>
-#include <kiconloader.h>
-#include <kglobal.h>
-#include <kmessagebox.h>
+#include <KDebug>
+#include <KGlobal>
+#include <KLocale>
+#include <KMessageBox>
 
-#include <q3intdict.h>
 #include <QDateTime>
 #include <QApplication>
 #include <QCursor>
@@ -64,10 +60,7 @@
 #include <QResizeEvent>
 #include <QMouseEvent>
 
-#include <assert.h>
-#include <math.h>
-
-#include "koagenda.moc"
+#include <cmath>
 
 ///////////////////////////////////////////////////////////////////////////////
 MarcusBains::MarcusBains( KOAgenda *agenda )
@@ -79,7 +72,7 @@ MarcusBains::MarcusBains( KOAgenda *agenda )
 
   mTimer = new QTimer( this );
   mTimer->setSingleShot( true );
-  connect( mTimer, SIGNAL(timeout()), this, SLOT(updateLocation()) );
+  connect( mTimer, SIGNAL(timeout()), this, SLOT(updateLocation(bool)) );
   mTimer->start( 0 );
 
   mOldTodayCol = -1;
@@ -184,7 +177,7 @@ void MarcusBains::updateLocation( bool recalculate )
 /*
   Create an agenda widget with rows rows and columns columns.
 */
-KOAgenda::KOAgenda( int columns, int rows, int rowSize, QWidget *parent,
+KOAgenda::KOAgenda( KOEventView *eventView, int columns, int rows, int rowSize, QWidget *parent,
                     Qt::WFlags f )
   : Q3ScrollView( parent, /*name*/0, f ), mHolidayMask( 0 ), mChanger( 0 )
 {
@@ -192,6 +185,7 @@ KOAgenda::KOAgenda( int columns, int rows, int rowSize, QWidget *parent,
   mRows = rows;
   mGridSpacingY = rowSize;
   mAllDayMode = false;
+  mEventView = eventView;
 
   init();
 
@@ -202,14 +196,15 @@ KOAgenda::KOAgenda( int columns, int rows, int rowSize, QWidget *parent,
   Create an agenda widget with columns columns and one row. This is used for
   all-day events.
 */
-KOAgenda::KOAgenda( int columns, QWidget *parent, Qt::WFlags f )
-  : Q3ScrollView( parent, /*name*/0, f )
+KOAgenda::KOAgenda( KOEventView *eventView, int columns, QWidget *parent, Qt::WFlags f )
+  : Q3ScrollView( parent, /*name*/0, f ), mHolidayMask( 0 ), mChanger( 0 )
 {
   mColumns = columns;
   mRows = 1;
   mGridSpacingY = 24;
   mAllDayMode = true;
   setVScrollBarMode( AlwaysOff );
+  mEventView = eventView;
 
   init();
 }
@@ -303,12 +298,7 @@ void KOAgenda::init()
   } else {
     mMarcusBains = new MarcusBains( this );
     addChild( mMarcusBains );
-  }
-
-  mTypeAhead = false;
-  mTypeAheadReceiver = 0;
-
-  mReturnPressed = false;
+  }  
 }
 
 void KOAgenda::clear()
@@ -474,84 +464,6 @@ bool KOAgenda::eventFilter_drag( QObject *object, QDropEvent *de )
   return false;
 }
 
-bool KOAgenda::eventFilter_key( QObject *, QKeyEvent *ke )
-{
-  // kDebug() << ke->type();
-
-  // If Return is pressed bring up an editor for the current selected time span.
-  if ( ke->key() == Qt::Key_Return ) {
-    if ( ke->type() == QEvent::KeyPress ) {
-      mReturnPressed = true;
-    } else if ( ke->type() == QEvent::KeyRelease ) {
-      if ( mReturnPressed ) {
-        emitNewEventForSelection();
-        mReturnPressed = false;
-        return true;
-      } else {
-        mReturnPressed = false;
-      }
-    }
-  }
-
-  // Ignore all input that does not produce any output
-  if ( ke->text().isEmpty() || ( ke->modifiers() & Qt::ControlModifier ) ) {
-    return false;
-  }
-
-  if ( ke->type() == QEvent::KeyPress ) {
-    switch ( ke->key() ) {
-    case Qt::Key_Escape:
-    case Qt::Key_Return:
-    case Qt::Key_Enter:
-    case Qt::Key_Tab:
-    case Qt::Key_Backtab:
-    case Qt::Key_Left:
-    case Qt::Key_Right:
-    case Qt::Key_Up:
-    case Qt::Key_Down:
-    case Qt::Key_Backspace:
-    case Qt::Key_Delete:
-    case Qt::Key_PageUp:
-    case Qt::Key_PageDown:
-    case Qt::Key_Home:
-    case Qt::Key_End:
-    case Qt::Key_Control:
-    case Qt::Key_Meta:
-    case Qt::Key_Alt:
-      break;
-    default:
-      mTypeAheadEvents.append( new QKeyEvent( ke->type(), ke->key(),
-                                              ke->modifiers(),
-                                              ke->text(), ke->isAutoRepeat(),
-                                              ke->count() ) );
-      if ( !mTypeAhead ) {
-        mTypeAhead = true;
-        emitNewEventForSelection();
-      }
-      return true;
-    }
-  }
-  return false;
-}
-
-void KOAgenda::emitNewEventForSelection()
-{
-  emit newEventSignal();
-}
-
-void KOAgenda::finishTypeAhead()
-{
-//  kDebug();
-  if ( typeAheadReceiver() ) {
-    foreach ( QEvent *e, mTypeAheadEvents ) {
-      QApplication::sendEvent( typeAheadReceiver(), e );
-    }
-  }
-  qDeleteAll( mTypeAheadEvents );
-  mTypeAheadEvents.clear();
-  mTypeAhead = false;
-}
-
 #ifndef QT_NO_WHEELEVENT
 bool KOAgenda::eventFilter_wheel ( QObject *object, QWheelEvent *e )
 {
@@ -585,6 +497,12 @@ bool KOAgenda::eventFilter_wheel ( QObject *object, QWheelEvent *e )
   return accepted;
 }
 #endif
+
+bool KOAgenda::eventFilter_key( QObject *, QKeyEvent *ke )
+{
+  return mEventView->processKeyEvent( ke );
+}
+
 bool KOAgenda::eventFilter_mouse( QObject *object, QMouseEvent *me )
 {
   QPoint viewportPos;
@@ -801,7 +719,7 @@ void KOAgenda::endSelectAction( const QPoint &currentPos )
   if ( KOPrefs::instance()->mSelectionStartsEditor ) {
     if ( ( mSelectionStartPoint - currentPos ).manhattanLength() >
          QApplication::startDragDistance() ) {
-       emitNewEventForSelection();
+       emit newEventSignal();
     }
   }
 }
@@ -1089,15 +1007,8 @@ void KOAgenda::endItemAction()
   if ( mItemMoved ) {
     bool modify = true;
     if ( mActionItem->incidence()->recurs() ) {
-      int res = KOMessageBox::fourBtnMsgBox(
-        this, QMessageBox::Question,
-        i18n( "The item you try to change is a recurring item. "
-              "Shall the changes be applied only to this single occurrence, "
-              "only to the future items, or to all items in the recurrence?" ),
-        i18n( "Changing Recurring Item" ),
-        KGuiItem( i18n( "Only &This Item" ) ),
-        KGuiItem( i18n( "Only &Future Items" ) ),
-        KGuiItem( i18n( "&All Occurrences" ) ) );
+      int res = mEventView->showMoveRecurDialog( mActionItem->incidence(),
+                                                 mActionItem->itemDate() );
       switch ( res ) {
       case KMessageBox::Ok: // All occurrences
         // Moving the whole sequene of events is handled by the itemModified below.
@@ -1941,11 +1852,11 @@ void KOAgenda::checkScrollBoundaries( int v )
 
   if ( yMin != mOldLowerScrollValue ) {
     mOldLowerScrollValue = yMin;
-    emit lowerYChanged(yMin);
+    emit lowerYChanged( yMin );
   }
   if ( yMax != mOldUpperScrollValue ) {
     mOldUpperScrollValue = yMax;
-    emit upperYChanged(yMax);
+    emit upperYChanged( yMax );
   }
 }
 
@@ -1966,7 +1877,17 @@ void KOAgenda::deselectItem()
   if ( mSelectedItem.isNull() ) {
     return;
   }
-  mSelectedItem->select(false);
+
+  Incidence *selectedInc = mSelectedItem->incidence();
+
+  foreach ( KOAgendaItem *item, mItems ) {
+    Incidence *itemInc = item->incidence();
+    if( itemInc && selectedInc &&
+        itemInc->uid() == selectedInc->uid() ) {
+      item->select( false );
+    }
+  }
+
   mSelectedItem = 0;
 }
 
@@ -1982,8 +1903,15 @@ void KOAgenda::selectItem( KOAgendaItem *item )
   }
   mSelectedItem = item;
   mSelectedItem->select();
-  assert( mSelectedItem->incidence() );
+  Q_ASSERT( mSelectedItem->incidence() );
   mSelectedUid = mSelectedItem->incidence()->uid();
+
+  foreach ( KOAgendaItem *item, mItems ) {
+    if( item->incidence() && item->incidence()->uid() == mSelectedUid ) {
+      item->select();
+    }
+  }
+
   emit incidenceSelected( mSelectedItem->incidence() );
 }
 
@@ -2055,12 +1983,5 @@ void KOAgenda::contentsMousePressEvent ( QMouseEvent *event )
   Q3ScrollView::contentsMousePressEvent( event );
 }
 
-void KOAgenda::setTypeAheadReceiver( QObject *o )
-{
-  mTypeAheadReceiver = o;
-}
 
-QObject *KOAgenda::typeAheadReceiver() const
-{
-  return mTypeAheadReceiver;
-}
+#include "koagenda.moc"
