@@ -29,12 +29,13 @@
 #include "koprefs.h"
 #include "koglobals.h"
 
-#include <kcal/incidence.h>
-#include <kcalendarsystem.h>
+#include <KCal/Incidence>
+
+#include <KCalendarSystem>
 
-#include <QPaintEvent>
-#include <QGraphicsSceneWheelEvent>
 #include <QGraphicsSceneMouseEvent>
+#include <QGraphicsSceneWheelEvent>
+#include <QPaintEvent>
 
 using namespace KOrg;
 
@@ -553,7 +554,7 @@ void MonthScene::mousePressEvent ( QGraphicsSceneMouseEvent *mouseEvent )
 
     selectItem( mClickedItem );
     if ( mouseEvent->button() == Qt::RightButton ) {
-      IncidenceMonthItem *tmp = dynamic_cast<IncidenceMonthItem *>( mClickedItem );
+      IncidenceMonthItem *tmp = qobject_cast<IncidenceMonthItem *>( mClickedItem );
       if ( tmp ) {
         emit showIncidencePopupSignal( mCalendar,
                                        tmp->incidence(), tmp->realStartDate() );
