@@ -1,8 +1,8 @@
-#ifndef _Time_Time_SETUP_H
-#define _Time_Time_SETUP_H
+#ifndef TIME_SETUP_H
+#define TIME_SETUP_H
 /* knotes-setup.h                       KPilot
 **
-** Copyright (C) 2002 by Reinhold Kainhofer
+** Copyright (C) 2002 by Reinhold Kainhofer <reinhold@kainhofer.com>
 **
 ** This file defines the widget and behavior for the config dialog
 ** of the KNotes conduit.
@@ -30,15 +30,24 @@
 */
 
 #include "plugin.h"
+#include "ui_time-setup_dialog.h"
 
-class TimeWidget;
 class KAboutData;
 
+class TimeWidget : public QWidget, public Ui::TimeWidget
+{
+public:
+  TimeWidget( QWidget *parent ) : QWidget( parent ) {
+    setupUi( this );
+  }
+};
+
+
 class TimeWidgetConfig : public ConduitConfigBase
 {
 Q_OBJECT
 public:
-	TimeWidgetConfig(QWidget *parent, const char *);
+	TimeWidgetConfig(QWidget *parent, const QVariantList &);
 	virtual void commit();
 	virtual void load();
 	static ConduitConfigBase *create(QWidget *,const char *);
