@@ -1,5 +1,5 @@
-#ifndef _KPILOT_PILOTRECORD_H
-#define _KPILOT_PILOTRECORD_H
+#ifndef KPILOT_PILOTRECORD_H
+#define KPILOT_PILOTRECORD_H
 /* KPilot
 **
 ** Copyright (C) 1998-2001 by Dan Pilone <dan@kpilot.org>
@@ -29,7 +29,7 @@
 ** Bug reports and questions can be sent to kde-pim@kde.org
 */
 
-
+// KPilot headers
 #include "pilot.h"
 
 /**
