@@ -29,74 +29,72 @@
  *  your version.
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
-#include <qapplication.h>
-#include <qlayout.h>
-#include <qprogressbar.h>
-#include <qtimer.h>
-#include <qheader.h>
-#include <qobject.h>
-#include <qscrollview.h>
-#include <qtoolbutton.h>
-#include <qpushbutton.h>
-#include <qvbox.h>
-#include <qtooltip.h>
-
-#include <klocale.h>
-#include <kdialog.h>
-#include <kstdguiitem.h>
-#include <kiconloader.h>
-#include <kdebug.h>
-
 #include "progressdialog.h"
 #include "progressmanager.h"
 #include "ssllabel.h"
-#include <qwhatsthis.h>
+
+#include <KDebug>
+#include <KDialog>
+#include <KHBox>
+#include <KIconLoader>
+#include <KLocale>
+#include <KStandardGuiItem>
+#include <KVBox>
+
+#include <QApplication>
+#include <QCloseEvent>
+#include <QEvent>
+#include <QFrame>
+#include <QLabel>
+#include <QLayout>
+#include <QObject>
+#include <QProgressBar>
+#include <QPushButton>
+#include <QScrollBar>
+#include <QTimer>
+#include <QToolButton>
 
 namespace KPIM {
 
+static const int MAX_LABEL_WIDTH = 650;
+
 class TransactionItem;
 
 TransactionItemView::TransactionItemView( QWidget * parent,
-                                          const char * name,
-                                          WFlags f )
-    : QScrollView( parent, name, f ) {
+                                          const char * name )
+    : QScrollArea( parent ) {
+  setObjectName( name );
   setFrameStyle( NoFrame );
-  mBigBox = new QVBox( viewport() );
-  mBigBox->setSpacing( 5 );
-  addChild( mBigBox );
-  setResizePolicy( QScrollView::AutoOneFit ); // Fit so that the box expands horizontally
+  mBigBox = new KVBox( this );
+  setWidget( mBigBox );
+  setWidgetResizable( true );
+  setSizePolicy( QSizePolicy::Preferred, QSizePolicy::Fixed );
 }
 
 TransactionItem* TransactionItemView::addTransactionItem( ProgressItem* item, bool first )
 {
-   TransactionItem *ti = new TransactionItem( mBigBox, item, first );
-   ti->hide();
-   QTimer::singleShot( 1000, ti, SLOT( show() ) );
-   return ti;
+ TransactionItem *ti = new TransactionItem( mBigBox, item, first );
+ mBigBox->layout()->addWidget( ti );
+
+ resize( mBigBox->width(), mBigBox->height() );
+
+ return ti;
 }
 
-void TransactionItemView::resizeContents( int w, int h )
+void TransactionItemView::resizeEvent ( QResizeEvent *event )
 {
-  // (handling of QEvent::LayoutHint in QScrollView calls this method)
-  //kdDebug(5300) << k_funcinfo << w << "," << h << endl;
-  QScrollView::resizeContents( w, h );
   // Tell the layout in the parent (progressdialog) that our size changed
   updateGeometry();
-  // Resize the parent (progressdialog) - this works but resize horizontally too often
-  //parentWidget()->adjustSize();
 
-  QApplication::sendPostedEvents( 0, QEvent::ChildInserted );
-  QApplication::sendPostedEvents( 0, QEvent::LayoutHint );
   QSize sz = parentWidget()->sizeHint();
   int currentWidth = parentWidget()->width();
+
   // Don't resize to sz.width() every time when it only reduces a little bit
   if ( currentWidth < sz.width() || currentWidth > sz.width() + 100 )
     currentWidth = sz.width();
   parentWidget()->resize( currentWidth, sz.height() );
+
+  QScrollArea::resizeEvent( event );
 }
 
 QSize TransactionItemView::sizeHint() const
@@ -112,14 +110,19 @@ QSize TransactionItemView::minimumSizeHint() const
   int minw = topLevelWidget()->width() / 3;
   int maxh = topLevelWidget()->height() / 2;
   QSize sz( mBigBox->minimumSizeHint() );
-  sz.setWidth( QMAX( sz.width(), minw ) + f + vsbExt );
-  sz.setHeight( QMIN( sz.height(), maxh ) + f );
+  sz.setWidth( qMax( sz.width(), minw ) + f + vsbExt );
+  sz.setHeight( qMin( sz.height(), maxh ) + f );
   return sz;
 }
 
 
 void TransactionItemView::slotLayoutFirstItem()
 {
+  //This slot is called whenever a TransactionItem is deleted, so this is a
+  //good place to call updateGeometry(), so our parent takes the new size
+  //into account and resizes.
+  updateGeometry();
+
   /*
      The below relies on some details in Qt's behaviour regarding deleting
      objects. This slot is called from the destroyed signal of an item just
@@ -129,8 +132,7 @@ void TransactionItemView::slotLayoutFirstItem()
      be the first item very shortly. That's the one we want to remove the
      hline for.
   */
-  QObject *o = mBigBox->child( "TransactionItem", "KPIM::TransactionItem" );
-  TransactionItem *ti = dynamic_cast<TransactionItem*>( o );
+  TransactionItem *ti = mBigBox->findChild<KPIM::TransactionItem*>( "TransactionItem" );
   if ( ti ) {
     ti->hideHLine();
   }
@@ -141,7 +143,7 @@ void TransactionItemView::slotLayoutFirstItem()
 
 TransactionItem::TransactionItem( QWidget* parent,
                                   ProgressItem *item, bool first )
-  : QVBox( parent, "TransactionItem" ), mCancelButton( 0 ), mItem( item )
+  : KVBox( parent ), mCancelButton( 0 ), mItem( item )
 
 {
   setSpacing( 2 );
@@ -153,39 +155,40 @@ TransactionItem::TransactionItem( QWidget* parent,
   mFrame->setFrameShadow( QFrame::Raised );
   mFrame->show();
   setStretchFactor( mFrame, 3 );
+  layout()->addWidget( mFrame );
 
-  QHBox *h = new QHBox( this );
+  KHBox *h = new KHBox( this );
   h->setSpacing( 5 );
+  layout()->addWidget( h );
 
-  mItemLabel = new QLabel( item->label(), h );
-  // always interpret the label text as RichText, but disable word wrapping
-  mItemLabel->setTextFormat( Qt::RichText );
-  mItemLabel->setAlignment( Qt::AlignAuto | Qt::AlignVCenter | Qt::SingleLine );
+  mItemLabel = new QLabel( fontMetrics().elidedText( item->label(), Qt::ElideRight, MAX_LABEL_WIDTH ), h );
+  h->layout()->addWidget( mItemLabel );
   h->setSizePolicy( QSizePolicy( QSizePolicy::Preferred, QSizePolicy::Fixed ) );
 
-  mProgress = new QProgressBar( 100, h );
-  mProgress->setProgress( item->progress() );
+  mProgress = new QProgressBar( h );
+  mProgress->setMaximum(100);
+  mProgress->setValue( item->progress() );
+  h->layout()->addWidget( mProgress );
 
   if ( item->canBeCanceled() ) {
-    mCancelButton = new QPushButton( SmallIcon( "cancel" ), QString::null, h );
-    QToolTip::add( mCancelButton, i18n("Cancel this operation.") );
+    mCancelButton = new QPushButton( SmallIcon( "list-remove" ), QString(), h );
+    mCancelButton->setToolTip( i18n("Cancel this operation.") );
     connect ( mCancelButton, SIGNAL( clicked() ),
               this, SLOT( slotItemCanceled() ));
+    h->layout()->addWidget( mCancelButton );
   }
 
-  h = new QHBox( this );
+  h = new KHBox( this );
   h->setSpacing( 5 );
   h->setSizePolicy( QSizePolicy( QSizePolicy::Preferred, QSizePolicy::Fixed ) );
+  layout()->addWidget( h );
   mSSLLabel = new SSLLabel( h );
   mSSLLabel->setSizePolicy( QSizePolicy( QSizePolicy::Fixed, QSizePolicy::Fixed ) );
-  mItemStatus = new QLabel( item->status(), h );
-  // always interpret the status text as RichText, but disable word wrapping
+  h->layout()->addWidget( mSSLLabel );
+  mItemStatus = new QLabel( h );
   mItemStatus->setTextFormat( Qt::RichText );
-  mItemStatus->setAlignment( Qt::AlignAuto | Qt::AlignVCenter | Qt::SingleLine );
-  // richtext leads to sizeHint acting as if wrapping was enabled though,
-  // so make sure we only ever have the height of one line.
-  mItemStatus->setSizePolicy( QSizePolicy( QSizePolicy::Preferred, QSizePolicy::Ignored ) );
-  mItemStatus->setFixedHeight( mItemLabel->sizeHint().height() );
+  mItemStatus->setText( fontMetrics().elidedText( item->status(), Qt::ElideRight, MAX_LABEL_WIDTH ) );
+  h->layout()->addWidget( mItemStatus );
   setCrypto( item->usesCrypto() );
   if( first ) hideHLine();
 }
@@ -196,22 +199,22 @@ TransactionItem::~TransactionItem()
 
 void TransactionItem::hideHLine()
 {
-    mFrame->hide();
+  mFrame->hide();
 }
 
 void TransactionItem::setProgress( int progress )
 {
-  mProgress->setProgress( progress );
+  mProgress->setValue( progress );
 }
 
 void TransactionItem::setLabel( const QString& label )
 {
-  mItemLabel->setText( label );
+  mItemLabel->setText( fontMetrics().elidedText( label, Qt::ElideRight, MAX_LABEL_WIDTH ) );
 }
 
 void TransactionItem::setStatus( const QString& status )
 {
-  mItemStatus->setText( status );
+  mItemStatus->setText( fontMetrics().elidedText( status, Qt::ElideRight, MAX_LABEL_WIDTH ) );
 }
 
 void TransactionItem::setCrypto( bool on )
@@ -242,45 +245,44 @@ void TransactionItem::addSubTransaction( ProgressItem* /*item*/ )
 ProgressDialog::ProgressDialog( QWidget* alignWidget, QWidget* parent, const char* name )
     : OverlayWidget( alignWidget, parent, name ), mWasLastShown( false )
 {
-    setFrameStyle( QFrame::Panel | QFrame::Sunken ); // QFrame
-    setSpacing( 0 ); // QHBox
-    setMargin( 1 );
+  setFrameStyle( QFrame::Panel | QFrame::Sunken ); // QFrame
 
-    mScrollView = new TransactionItemView( this, "ProgressScrollView" );
+  mScrollView = new TransactionItemView( this, "ProgressScrollView" );
+  layout()->addWidget( mScrollView );
 
-    // No more close button for now, since there is no more autoshow
-    /*
+  // No more close button for now, since there is no more autoshow
+  /*
     QVBox* rightBox = new QVBox( this );
     QToolButton* pbClose = new QToolButton( rightBox );
     pbClose->setAutoRaise(true);
     pbClose->setSizePolicy( QSizePolicy( QSizePolicy::Fixed, QSizePolicy::Fixed ) );
     pbClose->setFixedSize( 16, 16 );
-    pbClose->setIconSet( KGlobal::iconLoader()->loadIconSet( "fileclose", KIcon::Small, 14 ) );
-    QToolTip::add( pbClose, i18n( "Hide detailed progress window" ) );
+    pbClose->setIcon( KIconLoader::global()->loadIconSet( "window-close", KIconLoader::Small, 14 ) );
+    pbClose->setToolTip( i18n( "Hide detailed progress window" ) );
     connect(pbClose, SIGNAL(clicked()), this, SLOT(slotClose()));
     QWidget* spacer = new QWidget( rightBox ); // don't let the close button take up all the height
     rightBox->setStretchFactor( spacer, 100 );
-    */
+  */
 
-    /*
-     * Get the singleton ProgressManager item which will inform us of
-     * appearing and vanishing items.
-     */
-    ProgressManager *pm = ProgressManager::instance();
-    connect ( pm, SIGNAL( progressItemAdded( KPIM::ProgressItem* ) ),
-              this, SLOT( slotTransactionAdded( KPIM::ProgressItem* ) ) );
-    connect ( pm, SIGNAL( progressItemCompleted( KPIM::ProgressItem* ) ),
-              this, SLOT( slotTransactionCompleted( KPIM::ProgressItem* ) ) );
-    connect ( pm, SIGNAL( progressItemProgress( KPIM::ProgressItem*, unsigned int ) ),
-              this, SLOT( slotTransactionProgress( KPIM::ProgressItem*, unsigned int ) ) );
-    connect ( pm, SIGNAL( progressItemStatus( KPIM::ProgressItem*, const QString& ) ),
-              this, SLOT( slotTransactionStatus( KPIM::ProgressItem*, const QString& ) ) );
-    connect ( pm, SIGNAL( progressItemLabel( KPIM::ProgressItem*, const QString& ) ),
-              this, SLOT( slotTransactionLabel( KPIM::ProgressItem*, const QString& ) ) );
-    connect ( pm, SIGNAL( progressItemUsesCrypto(KPIM::ProgressItem*, bool) ),
-              this, SLOT( slotTransactionUsesCrypto( KPIM::ProgressItem*, bool ) ) );
-    connect ( pm, SIGNAL( showProgressDialog() ),
-              this, SLOT( slotShow() ) );
+  /*
+   * Get the singleton ProgressManager item which will inform us of
+   * appearing and vanishing items.
+   */
+  ProgressManager *pm = ProgressManager::instance();
+  connect ( pm, SIGNAL( progressItemAdded( KPIM::ProgressItem* ) ),
+            this, SLOT( slotTransactionAdded( KPIM::ProgressItem* ) ) );
+  connect ( pm, SIGNAL( progressItemCompleted( KPIM::ProgressItem* ) ),
+            this, SLOT( slotTransactionCompleted( KPIM::ProgressItem* ) ) );
+  connect ( pm, SIGNAL( progressItemProgress( KPIM::ProgressItem*, unsigned int ) ),
+            this, SLOT( slotTransactionProgress( KPIM::ProgressItem*, unsigned int ) ) );
+  connect ( pm, SIGNAL( progressItemStatus( KPIM::ProgressItem*, const QString& ) ),
+            this, SLOT( slotTransactionStatus( KPIM::ProgressItem*, const QString& ) ) );
+  connect ( pm, SIGNAL( progressItemLabel( KPIM::ProgressItem*, const QString& ) ),
+            this, SLOT( slotTransactionLabel( KPIM::ProgressItem*, const QString& ) ) );
+  connect ( pm, SIGNAL( progressItemUsesCrypto(KPIM::ProgressItem*, bool) ),
+            this, SLOT( slotTransactionUsesCrypto( KPIM::ProgressItem*, bool ) ) );
+  connect ( pm, SIGNAL( showProgressDialog() ),
+            this, SLOT( slotShow() ) );
 }
 
 void ProgressDialog::closeEvent( QCloseEvent* e )
@@ -300,37 +302,37 @@ ProgressDialog::~ProgressDialog()
 
 void ProgressDialog::slotTransactionAdded( ProgressItem *item )
 {
-   TransactionItem *parent = 0;
-   if ( item->parent() ) {
-     if ( mTransactionsToListviewItems.contains( item->parent() ) ) {
-       parent = mTransactionsToListviewItems[ item->parent() ];
-       parent->addSubTransaction( item );
-     }
-   } else {
-     const bool first = mTransactionsToListviewItems.empty();
-     TransactionItem *ti = mScrollView->addTransactionItem( item, first );
-     if ( ti )
-       mTransactionsToListviewItems.replace( item, ti );
-     if ( first && mWasLastShown )
-       QTimer::singleShot( 1000, this, SLOT( slotShow() ) );
+  TransactionItem *parent = 0;
+  if ( item->parent() ) {
+    if ( mTransactionsToListviewItems.contains( item->parent() ) ) {
+      parent = mTransactionsToListviewItems[ item->parent() ];
+      parent->addSubTransaction( item );
+    }
+  } else {
+    const bool first = mTransactionsToListviewItems.empty();
+    TransactionItem *ti = mScrollView->addTransactionItem( item, first );
+    if ( ti )
+      mTransactionsToListviewItems.insert( item, ti );
+    if ( first && mWasLastShown )
+      QTimer::singleShot( 1000, this, SLOT( slotShow() ) );
 
-   }
+  }
 }
 
 void ProgressDialog::slotTransactionCompleted( ProgressItem *item )
 {
-   if ( mTransactionsToListviewItems.contains( item ) ) {
-     TransactionItem *ti = mTransactionsToListviewItems[ item ];
-     mTransactionsToListviewItems.remove( item );
-     ti->setItemComplete();
-     QTimer::singleShot( 3000, ti, SLOT( deleteLater() ) );
-     // see the slot for comments as to why that works
-     connect ( ti, SIGNAL( destroyed() ),
-               mScrollView, SLOT( slotLayoutFirstItem() ) );
-   }
-   // This was the last item, hide.
-   if ( mTransactionsToListviewItems.empty() )
-     QTimer::singleShot( 3000, this, SLOT( slotHide() ) );
+  if ( mTransactionsToListviewItems.contains( item ) ) {
+    TransactionItem *ti = mTransactionsToListviewItems[ item ];
+    mTransactionsToListviewItems.remove( item );
+    ti->setItemComplete();
+    QTimer::singleShot( 3000, ti, SLOT( deleteLater() ) );
+    // see the slot for comments as to why that works
+    connect ( ti, SIGNAL( destroyed() ),
+              mScrollView, SLOT( slotLayoutFirstItem() ) );
+  }
+  // This was the last item, hide.
+  if ( mTransactionsToListviewItems.empty() )
+    QTimer::singleShot( 3000, this, SLOT( slotHide() ) );
 }
 
 void ProgressDialog::slotTransactionCanceled( ProgressItem* )
@@ -340,43 +342,43 @@ void ProgressDialog::slotTransactionCanceled( ProgressItem* )
 void ProgressDialog::slotTransactionProgress( ProgressItem *item,
                                               unsigned int progress )
 {
-   if ( mTransactionsToListviewItems.contains( item ) ) {
-     TransactionItem *ti = mTransactionsToListviewItems[ item ];
-     ti->setProgress( progress );
-   }
+  if ( mTransactionsToListviewItems.contains( item ) ) {
+    TransactionItem *ti = mTransactionsToListviewItems[ item ];
+    ti->setProgress( progress );
+  }
 }
 
 void ProgressDialog::slotTransactionStatus( ProgressItem *item,
                                             const QString& status )
 {
-   if ( mTransactionsToListviewItems.contains( item ) ) {
-     TransactionItem *ti = mTransactionsToListviewItems[ item ];
-     ti->setStatus( status );
-   }
+  if ( mTransactionsToListviewItems.contains( item ) ) {
+    TransactionItem *ti = mTransactionsToListviewItems[ item ];
+    ti->setStatus( status );
+  }
 }
 
 void ProgressDialog::slotTransactionLabel( ProgressItem *item,
                                            const QString& label )
 {
-   if ( mTransactionsToListviewItems.contains( item ) ) {
-     TransactionItem *ti = mTransactionsToListviewItems[ item ];
-     ti->setLabel( label );
-   }
+  if ( mTransactionsToListviewItems.contains( item ) ) {
+    TransactionItem *ti = mTransactionsToListviewItems[ item ];
+    ti->setLabel( label );
+  }
 }
 
 
 void ProgressDialog::slotTransactionUsesCrypto( ProgressItem *item,
                                                 bool value )
 {
-   if ( mTransactionsToListviewItems.contains( item ) ) {
-     TransactionItem *ti = mTransactionsToListviewItems[ item ];
-     ti->setCrypto( value );
-   }
+  if ( mTransactionsToListviewItems.contains( item ) ) {
+    TransactionItem *ti = mTransactionsToListviewItems[ item ];
+    ti->setCrypto( value );
+  }
 }
 
 void ProgressDialog::slotShow()
 {
-   setVisible( true );
+  setVisible( true );
 }
 
 void ProgressDialog::slotHide()
@@ -395,10 +397,7 @@ void ProgressDialog::slotClose()
 
 void ProgressDialog::setVisible( bool b )
 {
-  if ( b )
-    show();
-  else
-    hide();
+  OverlayWidget::setVisible( b );
   emit visibilityChanged( b );
 }
 
@@ -409,9 +408,9 @@ void ProgressDialog::slotToggleVisibility()
    * the statusbarwidget should not display the dialog, because there
    * are no items to be shown anymore. Guard against that.
    */
-  mWasLastShown = !isShown();
-  if ( isShown() || !mTransactionsToListviewItems.isEmpty() )
-    setVisible( !isShown() );
+  mWasLastShown = isHidden();
+  if ( !isHidden() || !mTransactionsToListviewItems.isEmpty() )
+    setVisible( isHidden() );
 }
 
 }
