@@ -78,6 +78,7 @@ QGpgMECryptoConfig::QGpgMECryptoConfig()
 
 QGpgMECryptoConfig::~QGpgMECryptoConfig()
 {
+    clear();
 }
 
 void QGpgMECryptoConfig::runGpgConf( bool showErrors )
@@ -133,44 +134,53 @@ void QGpgMECryptoConfig::slotCollectStdOut()
     // Format: NAME:DESCRIPTION
     const QStringList lst = line.split( ':' );
     if ( lst.count() >= 2 ) {
-      mComponents.insert( lst[0], new QGpgMECryptoConfigComponent( this, lst[0], lst[1] ) );
+        const std::pair<QString,QGpgMECryptoConfigComponent*> pair( lst[0], new QGpgMECryptoConfigComponent( this, lst[0], lst[1] ) );
+        mComponentsNaturalOrder.push_back( pair );
+        mComponentsByName[pair.first] = pair.second;
     } else {
       kWarning(5150) <<"Parse error on gpgconf --list-components output:" << line;
     }
   }
 }
 
+namespace {
+    struct Select1St {
+        template <typename U, typename V>
+        const U & operator()( const std::pair<U,V> & p ) const { return p.first; }
+        template <typename U, typename V>
+        const U & operator()( const QPair<U,V> & p ) const { return p.first; }
+    };
+}
+
 QStringList QGpgMECryptoConfig::componentList() const
 {
   if ( !mParsed )
     const_cast<QGpgMECryptoConfig*>( this )->runGpgConf( true );
-  QStringList names;
-  QList<QString> keylist = mComponents.uniqueKeys();
-  foreach (QString key, keylist) {
-	names << key;
-  }
-  return names;
+  QStringList result;
+  std::transform( mComponentsNaturalOrder.begin(), mComponentsNaturalOrder.end(),
+                  std::back_inserter( result ), Select1St() );
+  return result;
 }
 
 Kleo::CryptoConfigComponent* QGpgMECryptoConfig::component( const QString& name ) const
 {
   if ( !mParsed )
     const_cast<QGpgMECryptoConfig*>( this )->runGpgConf( false );
-  return mComponents.value( name );
+  return mComponentsByName.value( name );
 }
 
 void QGpgMECryptoConfig::sync( bool runtime )
 {
-  foreach (QGpgMECryptoConfigComponent *it, mComponents){
-  	it->sync(runtime);
-  }
+  Q_FOREACH (QGpgMECryptoConfigComponent *it, mComponentsByName)
+      it->sync(runtime);
 }
 
 void QGpgMECryptoConfig::clear()
 {
   s_duringClear = true;
-  qDeleteAll(mComponents);
-  mComponents.clear();
+  mComponentsNaturalOrder.clear();
+  qDeleteAll(mComponentsByName);
+  mComponentsByName.clear();
   s_duringClear = false;
   mParsed = false; // next call to componentList/component will need to run gpgconf again
 }
@@ -185,8 +195,9 @@ QGpgMECryptoConfigComponent::QGpgMECryptoConfigComponent( QGpgMECryptoConfig*, c
 
 QGpgMECryptoConfigComponent::~QGpgMECryptoConfigComponent()
 {
-  qDeleteAll(mGroups);
-  mGroups.clear();
+  mGroupsNaturalOrder.clear();
+  qDeleteAll(mGroupsByName);
+  mGroupsByName.clear();
 }
 
 void QGpgMECryptoConfigComponent::runGpgConf()
@@ -223,8 +234,10 @@ void QGpgMECryptoConfigComponent::runGpgConf()
   if( rc != 0 ) // can happen when using the wrong version of gpg...
     kWarning(5150) <<"Running 'gpgconf --list-options" << mName <<"' failed." << strerror( rc ) <<", but try that command to see the real output";
   else {
-    if ( mCurrentGroup && !mCurrentGroup->mEntries.isEmpty() ) // only add non-empty groups
-      mGroups.insert( mCurrentGroupName, mCurrentGroup );
+    if ( mCurrentGroup && !mCurrentGroup->mEntriesNaturalOrder.empty() ) { // only add non-empty groups
+      mGroupsByName.insert( mCurrentGroupName, mCurrentGroup );
+      mGroupsNaturalOrder.push_back( std::make_pair( mCurrentGroupName, mCurrentGroup ) );
+    }
   }
 }
 
@@ -247,8 +260,10 @@ void QGpgMECryptoConfigComponent::slotCollectStdOut()
       if ( level > 2 ) // invisible or internal -> skip it;
         continue;
       if ( flags & GPGCONF_FLAG_GROUP ) {
-        if ( mCurrentGroup && !mCurrentGroup->mEntries.isEmpty() ) // only add non-empty groups
-          mGroups.insert( mCurrentGroupName, mCurrentGroup );
+        if ( mCurrentGroup && !mCurrentGroup->mEntriesNaturalOrder.empty() ) { // only add non-empty groups
+          mGroupsByName.insert( mCurrentGroupName, mCurrentGroup );
+          mGroupsNaturalOrder.push_back( std::make_pair( mCurrentGroupName, mCurrentGroup ) );
+        }
         //else
         //  kDebug(5150) <<"Discarding empty group" << mCurrentGroupName;
         mCurrentGroup = new QGpgMECryptoConfigGroup( this, lst[0], lst[3], level );
@@ -259,7 +274,10 @@ void QGpgMECryptoConfigComponent::slotCollectStdOut()
           mCurrentGroup = new QGpgMECryptoConfigGroup( this, "<nogroup>", QString(), 0 );
           mCurrentGroupName = "<nogroup>";
         }
-        mCurrentGroup->mEntries.insert( lst[0], new QGpgMECryptoConfigEntry( mCurrentGroup, lst ) );
+        const QString & name = lst[0];
+        QGpgMECryptoConfigEntry * value = new QGpgMECryptoConfigEntry( mCurrentGroup, lst );
+        mCurrentGroup->mEntriesByName.insert( name, value );
+        mCurrentGroup->mEntriesNaturalOrder.push_back( std::make_pair( name, value ) );
       }
     } else {
       // This happens on lines like
@@ -272,17 +290,15 @@ void QGpgMECryptoConfigComponent::slotCollectStdOut()
 
 QStringList QGpgMECryptoConfigComponent::groupList() const
 {
-  QStringList names;
-  QList<QString> keylist = mGroups.uniqueKeys();
-  foreach (QString key, keylist) {
-        names << key;
-  }
-  return names;
+  QStringList result;
+  std::transform( mGroupsNaturalOrder.begin(), mGroupsNaturalOrder.end(),
+                  std::back_inserter( result ), Select1St() );
+  return result;
 }
 
 Kleo::CryptoConfigGroup* QGpgMECryptoConfigComponent::group(const QString& name ) const
 {
-  return mGroups.value( name );
+  return mGroupsByName.value( name );
 }
 
 void QGpgMECryptoConfigComponent::sync( bool runtime )
@@ -293,11 +309,11 @@ void QGpgMECryptoConfigComponent::sync( bool runtime )
   QList<QGpgMECryptoConfigEntry *> dirtyEntries;
 
   // Collect all dirty entries
-  QList<QString> keylist = mGroups.uniqueKeys();
-  foreach (QString key, keylist) {
-    QHash<QString,QGpgMECryptoConfigEntry*> entry = mGroups[key]->mEntries;
-    QList<QString> keylistentry = entry.uniqueKeys();
-    foreach (QString keyentry, keylistentry) {
+  const QList<QString> keylist = mGroupsByName.uniqueKeys();
+  Q_FOREACH (const QString & key, keylist) {
+    const QHash<QString,QGpgMECryptoConfigEntry*> entry = mGroupsByName[key]->mEntriesByName;
+    const QList<QString> keylistentry = entry.uniqueKeys();
+    Q_FOREACH (const QString & keyentry, keylistentry) {
       if(entry[keyentry]->isDirty())
       {
        // OK, we can set it.currentKey() to it.current()->outputString()
@@ -359,8 +375,8 @@ void QGpgMECryptoConfigComponent::sync( bool runtime )
   }
   else
   {
-    QList<QGpgMECryptoConfigEntry *>::Iterator it = dirtyEntries.begin();
-    for( ; it != dirtyEntries.end(); ++it ) {
+    QList<QGpgMECryptoConfigEntry *>::const_iterator it = dirtyEntries.constBegin();
+    for( ; it != dirtyEntries.constEnd(); ++it ) {
       (*it)->setDirty( false );
     }
   }
@@ -379,23 +395,22 @@ QGpgMECryptoConfigGroup::QGpgMECryptoConfigGroup( QGpgMECryptoConfigComponent *
 
 QGpgMECryptoConfigGroup::~QGpgMECryptoConfigGroup()
 {
-  qDeleteAll(mEntries);
-  mEntries.clear();
+  mEntriesNaturalOrder.clear();
+  qDeleteAll(mEntriesByName);
+  mEntriesByName.clear();
 }
 
 QStringList QGpgMECryptoConfigGroup::entryList() const
 {
-  QStringList names;
-  QList<QString> keylist = mEntries.uniqueKeys();
-  foreach (QString key, keylist) {
-        names << key;
-  }
-  return names;
+  QStringList result;
+  std::transform( mEntriesNaturalOrder.begin(), mEntriesNaturalOrder.end(),
+                  std::back_inserter( result ), Select1St() );
+  return result;
 }
 
 Kleo::CryptoConfigEntry* QGpgMECryptoConfigGroup::entry( const QString& name ) const
 {
-  return mEntries.value( name );
+  return mEntriesByName.value( name );
 }
 
 ////
@@ -456,7 +471,7 @@ QGpgMECryptoConfigEntry::QGpgMECryptoConfigEntry( QGpgMECryptoConfigGroup * grou
 {
   // Format: NAME:FLAGS:LEVEL:DESCRIPTION:TYPE:ALT-TYPE:ARGNAME:DEFAULT:ARGDEF:VALUE
   assert( parsedLine.count() >= 10 ); // called checked for it already
-  QStringList::const_iterator it = parsedLine.begin();
+  QStringList::const_iterator it = parsedLine.constBegin();
   mName = *it++;
   mFlags = (*it++).toInt();
   mLevel = (*it++).toInt();
@@ -499,12 +514,12 @@ QGpgMECryptoConfigEntry::QGpgMECryptoConfigEntry( QGpgMECryptoConfigGroup * grou
 
 QVariant QGpgMECryptoConfigEntry::stringToValue( const QString& str, bool unescape ) const
 {
-  bool isString = isStringType();
+  const bool isString = isStringType();
 
   if ( isList() ) {
     QList<QVariant> lst;
     QStringList items = str.split( ',', QString::SkipEmptyParts );
-    for( QStringList::const_iterator valit = items.begin(); valit != items.end(); ++valit ) {
+    for( QStringList::const_iterator valit = items.constBegin(); valit != items.constEnd(); ++valit ) {
       QString val = *valit;
       if ( isString ) {
         if ( val.isEmpty() ) {
@@ -601,11 +616,18 @@ static KUrl parseURL( int mRealArgType, const QString& str )
     // The format is HOSTNAME:PORT:USERNAME:PASSWORD:BASE_DN
     QStringList items = str.split( ':' );
     if ( items.count() == 5 ) {
-      QStringList::const_iterator it = items.begin();
+      QStringList::const_iterator it = items.constBegin();
       KUrl url;
       url.setProtocol( "ldap" );
       url.setHost( urlpart_decode( *it++ ) );
-      url.setPort( (*it++).toInt() );
+
+      bool ok;
+      const int port = (*it++).toInt( &ok );
+      if ( ok )
+          url.setPort( port );
+      else if ( !it->isEmpty() )
+          kWarning(5150) <<"parseURL: malformed LDAP server port, ignoring: \"" << *it << "\"";
+
       url.setPath( "/" ); // workaround KUrl parsing bug
       url.setUser( urlpart_decode( *it++ ) );
       url.setPass( urlpart_decode( *it++ ) );
@@ -625,7 +647,7 @@ static QString splitURL( int mRealArgType, const KUrl& url )
     // The format is HOSTNAME:PORT:USERNAME:PASSWORD:BASE_DN
     Q_ASSERT( url.protocol() == "ldap" );
     return urlpart_encode( url.host() ) + ':' +
-      QString::number( url.port() ) + ':' +
+      ( url.port() != -1 ? QString::number( url.port() ) : QString() ) + ':' + // -1 is used for default ports, omit
       urlpart_encode( url.user() ) + ':' +
       urlpart_encode( url.pass() ) + ':' +
       // KUrl automatically encoded the query (e.g. for spaces inside it),
@@ -669,7 +691,7 @@ QList<int> QGpgMECryptoConfigEntry::intValueList() const
   Q_ASSERT( isList() );
   QList<int> ret;
   QList<QVariant> lst = mValue.toList();
-  for( QList<QVariant>::const_iterator it = lst.begin(); it != lst.end(); ++it ) {
+  for( QList<QVariant>::const_iterator it = lst.constBegin(); it != lst.constEnd(); ++it ) {
     ret.append( (*it).toInt() );
   }
   return ret;
@@ -681,7 +703,7 @@ QList<unsigned int> QGpgMECryptoConfigEntry::uintValueList() const
   Q_ASSERT( isList() );
   QList<unsigned int> ret;
   QList<QVariant> lst = mValue.toList();
-  for( QList<QVariant>::const_iterator it = lst.begin(); it != lst.end(); ++it ) {
+  for( QList<QVariant>::const_iterator it = lst.constBegin(); it != lst.constEnd(); ++it ) {
     ret.append( (*it).toUInt() );
   }
   return ret;
@@ -694,7 +716,7 @@ KUrl::List QGpgMECryptoConfigEntry::urlValueList() const
   QStringList lst = mValue.toStringList();
 
   KUrl::List ret;
-  for( QStringList::const_iterator it = lst.begin(); it != lst.end(); ++it ) {
+  for( QStringList::const_iterator it = lst.constBegin(); it != lst.constEnd(); ++it ) {
     if ( mArgType == ArgType_Path ) {
       KUrl url;
       url.setPath( *it );
@@ -787,7 +809,7 @@ void QGpgMECryptoConfigEntry::setStringValueList( const QStringList& lst )
 void QGpgMECryptoConfigEntry::setIntValueList( const QList<int>& lst )
 {
   QList<QVariant> ret;
-  for( QList<int>::const_iterator it = lst.begin(); it != lst.end(); ++it ) {
+  for( QList<int>::const_iterator it = lst.constBegin(); it != lst.constEnd(); ++it ) {
     ret << QVariant( *it );
   }
   mValue = ret;
@@ -801,7 +823,7 @@ void QGpgMECryptoConfigEntry::setIntValueList( const QList<int>& lst )
 void QGpgMECryptoConfigEntry::setUIntValueList( const QList<unsigned int>& lst )
 {
   QList<QVariant> ret;
-  for( QList<unsigned int>::const_iterator it = lst.begin(); it != lst.end(); ++it ) {
+  for( QList<unsigned int>::const_iterator it = lst.constBegin(); it != lst.constEnd(); ++it ) {
     ret << QVariant( *it );
   }
   if ( ret.isEmpty() && !isOptional() )
@@ -815,7 +837,7 @@ void QGpgMECryptoConfigEntry::setUIntValueList( const QList<unsigned int>& lst )
 void QGpgMECryptoConfigEntry::setURLValueList( const KUrl::List& urls )
 {
   QStringList lst;
-  for( KUrl::List::const_iterator it = urls.begin(); it != urls.end(); ++it ) {
+  for( KUrl::List::const_iterator it = urls.constBegin(); it != urls.constEnd(); ++it ) {
     lst << splitURL( mRealArgType, *it );
   }
   mValue = lst;
@@ -865,7 +887,7 @@ QString QGpgMECryptoConfigEntry::toString( bool escape ) const
     return QString::number( numberOfTimesSet() );
   QStringList ret;
   QList<QVariant> lst = mValue.toList();
-  for( QList<QVariant>::const_iterator it = lst.begin(); it != lst.end(); ++it ) {
+  for( QList<QVariant>::const_iterator it = lst.constBegin(); it != lst.constEnd(); ++it ) {
       ret << (*it).toString(); // QVariant does the conversion
   }
   return ret.join( "," );
